/*
 * $RCSfile: Environment.cc,v $
 * $Revision: 1.5 $
 *
 * Comments:
 *
 * (C) Copyright ParaSoft Corporation 1996.  All rights reserved.
 * THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF ParaSoft
 * The copyright notice above does not evidence any
 * actual or intended publication of such source code.
 *
 * $Author: dario $          $Locker:  $
 * $Date: 2007-10-15 13:31:29 $
 * $Log: not supported by cvs2svn $
 * Revision 1.4  2005/11/21 11:39:45  dario
 * getEnvironment added.
 *
 * Revision 1.3  2005/11/17 10:12:32  dario
 * setenv added.
 *
 * Revision 1.2  2005/11/15 12:07:26  dario
 * include added.
 *
 * Revision 1.1  2005/11/15 11:50:07  jez
 * New file.
 *
 */
 
#include "Environment.h"
#include <windows.h>

const char* Environment::getenv(const char* name)
{
    DWORD size = GetEnvironmentVariable(name, NULL, 0);
    if (size > 0) {
        char *buffer = new char [size];
        DWORD newSize = GetEnvironmentVariable(name, buffer, size);
        if (newSize > 0) {
            return buffer;
        }
    }
    return 0;
}

char** Environment::getEnvironment(int& count)
{
	char** lpszResult;
	LPVOID lpvEnv = GetEnvironmentStrings();
    if (lpvEnv == NULL){
       return 0;
    }
        
	// Count environment variables
	count = 0;
	for (LPTSTR lpszVariable = (LPTSTR)lpvEnv; *lpszVariable; lpszVariable++) {
	    count++;
	    lpszVariable += strlen(lpszVariable);
	}	
	
	// Make copy of environment block
    lpszResult = new char*[count];
    int iCounter = 0;
    for (LPTSTR lpszVariable = (LPTSTR)lpvEnv; *lpszVariable; lpszVariable++, iCounter++) {
        int strLen = strlen(lpszVariable);
        lpszResult[iCounter] = new char[strLen + 1];
        strcpy(lpszResult[iCounter], lpszVariable);
        lpszVariable += strLen;
    }
	// Free original environment block
	FreeEnvironmentStrings((LPSTR)lpvEnv);
	
	fixEncoding(lpszResult, count);
	return lpszResult;
}


void Environment::setenv(const char* name, const char* value)
{
	SetEnvironmentVariable(name, value);	
}

char* Environment::envName(const char* lpszVariable)
{
	int len = 0;
	while (lpszVariable[len] != '=') {
	    len++;
	}
	if (len == 0) {
		return NULL;
	}

    char* name = new char[len + 1];
    strncpy(name, lpszVariable, len);
	name[len] = '\0';
	return name;
}

//
// GetEnvironmentStrings has problem with encodings so we need call
// GetEnvironmentVariable (returns good encoding) for each variable
// to ensure that encoding is ok
//
void Environment::fixEncoding(char** env, int count)
{
	for (int iCounter = 0; iCounter < count; iCounter++) {
		
		char* lpszName = envName(env[iCounter]);
		if (lpszName == NULL) {
			continue;
		}
		int nameLen = strlen(lpszName);
			
    	const char* lpszValue = this->getenv(lpszName);
    	
    	if (lpszValue == NULL) {
    	    delete[] lpszName;
    	    continue;
    	}
    	
    	char* lpszOrigValue = env[iCounter] + nameLen + 1;
    	
    	int valueLen = strlen(lpszValue);
    	
		if (strcmp(lpszValue, lpszOrigValue)) {
			if (valueLen == strlen(lpszOrigValue)) {
			    strncpy(lpszOrigValue, lpszValue, valueLen);
			}
		} else {
		    char* lpszVariable = new char[nameLen + valueLen + 2];
		    strncpy(lpszVariable, lpszName, nameLen);
		    lpszVariable[nameLen] = '=';
		    strcpy(lpszVariable + nameLen + 1, lpszValue);
		    delete[] env[iCounter];
		    env[iCounter] = lpszVariable;
		}
		
		delete[] lpszName;		
		delete[] lpszValue;
	}
}

