<?xml version="1.0"?>
<!-- in case of any change in xsl/xml file modify all connected xsl and xml files from this package  -->

<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:saxon="http://icl.com/saxon" xmlns:textutil="textutil" xmlns:graph="graph" xmlns:results="results" extension-element-prefixes="saxon">
  
	<!-- =================  print execution menu ============================ -->
    
    <xsl:template name="display_execution_menu">
	<xsl:param name="auth"/>
    
    <xsl:variable name="href" saxon:assignable="yes">#te</xsl:variable>
    <xsl:if test="$auth">
    	<saxon:assign name="href" select="concat('#tet_',$auth)"/>    	
    </xsl:if>

    <xsl:if test="($execution) > 0">
    	<xsl:call-template name="display_linked_menu_item">
	        <xsl:with-param name="text" select="$RES_PARAMETER_TEST_EXECUTION" />
	        <xsl:with-param name="link" select="$href" />
        </xsl:call-template>               
    </xsl:if>

    </xsl:template>

    <!-- =================  print execution ============================ -->
    
    <xsl:template name="display_execution">

    <!-- print test execution header -->
    <xsl:if test="($execution) > 0">
    
       <xsl:call-template name="summary_section_header">
         <xsl:with-param name="ref">te</xsl:with-param>
          <xsl:with-param name="id">execution_summary_section</xsl:with-param>
          <xsl:with-param name="label" select="$RES_PARAMETER_SUMMARY_TEST_EXECUTION"/>      
       </xsl:call-template>

       <xsl:call-template name="te_summary_charts"/>
        
	   <xsl:call-template name="collapsible_section_header">
			<xsl:with-param name="id">execution_details_section</xsl:with-param>
			<xsl:with-param name="label" select="$RES_PARAMETER_DETAILS_TEST_EXECUTION"/>		
       </xsl:call-template>
	   <div id="execution_details_section">
       <xsl:call-template name="exec_header"/>

       <xsl:if test="($generate_graphs = 'true')">
          <xsl:if test="($exec_tc_history) > 0">
             <br/>
             <xsl:call-template name="generate_graph">
                <xsl:with-param name="graph" select="/ResultsSession/Exec/History/Graph[@id=$exec_testcases_graph_id]"/>
                <xsl:with-param name="img_name" select="concat('unit_exc_tc_',$org_time)"/>
             </xsl:call-template>
          </xsl:if>
          <xsl:if test="($exec_history) > 0">
             <br/>
             <xsl:call-template name="generate_graph">
                <xsl:with-param name="graph" select="/ResultsSession/Exec/History/Graph[@id=$exec_tasks_graph_id]"/>
                <xsl:with-param name="img_name" select="concat('unit_exc_',$org_time)"/>
             </xsl:call-template>    
          </xsl:if>
       </xsl:if>
    
    <br/>
        
    <xsl:call-template name="exec_summary"/>
    <br/>
    <xsl:if test="($exec_errors_nmb) > 0">
    <xsl:call-template name="exec_errors_summary"/>     
    <br/>
    </xsl:if>

    <xsl:if test="not($report.mail.compact = $trends) or not(($report_type) = ($email_report))">

    <xsl:if test="($report.authors_details) = 'true'">
       <br/>
       <xsl:call-template name="te_authors_summary"/>
       
       <!-- print test execution error details for each auth -->
    
       <xsl:if test="($report.developer_errors) = 'true'">
          <br/>
          <table width='{$width}' cellpadding='0' cellspacing='0'>
             <xsl:if test="($report_format_mode='pdf')">
                <xsl:attribute name="cols">50% 25% 25%</xsl:attribute>
             </xsl:if>
             <xsl:call-template name="exec_details"/>
          </table>
       </xsl:if>
    </xsl:if>
          
    <xsl:if test="($report.contexts_details) = 'true'">
        <br/>
        <xsl:call-template name="executed_tests_details"/>
    </xsl:if>
    </xsl:if>
    
    <!-- print execution coverage section -->
    
    <xsl:if test="($exec_cvg) > 0">
       <xsl:call-template name="te_coverage_header"/>    
       <xsl:if test="($generate_graphs = 'true') and ($exec_cvg_history) > 0">
          <br/>
          <xsl:call-template name="generate_graph">
             <xsl:with-param name="graph" select="/ResultsSession/Exec/Coverage/History/Graph[@id=$exec_cvg_graph_id]"/>
             <xsl:with-param name="img_name" select="concat('unit_cvg_',$org_time)"/>
          </xsl:call-template>
          <br/>
       </xsl:if>
    </xsl:if>
    
    <xsl:if test="not($report.mail.compact = $trends) or not(($report_type) = ($email_report))">
    <xsl:if test="($exec_cvg) > 0">
        <!-- print execution coverage section -->
        <xsl:call-template name="exec_coverage_summary"/>
        <br/>
    </xsl:if>
    </xsl:if>
    
    </div>
    </xsl:if>
    </xsl:template>        

    <!-- =================  print execution summary charts ============= -->
    
    <xsl:template name="te_summary_charts">

        <xsl:variable name="total_test_cases" saxon:assignable="yes" select="sum(/ResultsSession/Exec/Projects/Project/@total)"/>
        <xsl:if test="string-length($total_test_cases) = 0">
           <saxon:assign name="total_test_cases" select="0"/>
        </xsl:if>
        <xsl:variable name="total_pass_test_cases" saxon:assignable="yes" select="sum(/ResultsSession/Exec/Projects/Project/@pass)"/>
        <xsl:if test="string-length($total_pass_test_cases) = 0">
           <saxon:assign name="total_pass_test_cases" select="0"/>
        </xsl:if>
        <xsl:variable name="total_fail_test_cases" saxon:assignable="yes" select="sum(/ResultsSession/Exec/Projects/Project/@fail)"/>
        <xsl:if test="string-length($total_fail_test_cases) = 0">
           <saxon:assign name="total_fail_test_cases" select="0"/>
        </xsl:if>
       
        <table width='{$width}' cellpadding='0' cellspacing='0'>
          <xsl:if test="($report_format_mode='pdf')">
             <xsl:variable name="cvg_type_count" select="count(/ResultsSession/Exec/Coverage/Types/CvgType)"/>
        
             <xsl:variable name="required_cols" select="1 + $cvg_type_count"/>  
             <xsl:if test="($required_cols) = 1">
                <xsl:attribute name="cols">100%</xsl:attribute>
             </xsl:if>                                          
             <xsl:if test="($required_cols) = 2">
                <xsl:attribute name="cols">50% 50%</xsl:attribute>
             </xsl:if>
             <xsl:if test="($required_cols) = 3">
                <xsl:attribute name="cols">33% 33% 33%</xsl:attribute>
             </xsl:if>
          </xsl:if>
          <tr>
          <xsl:if test="not($report_format_mode='pdf')">
             <td width="5%"></td>
          </xsl:if>
          <td>
          <xsl:variable name="pass_tests_percent" select="concat(textutil:getPercent($total_pass_test_cases, $total_fail_test_cases),'%')"/>
          
          <xsl:call-template name="generate_ring_chart">
             <xsl:with-param name="title"><xsl:value-of select="$RES_PARAMETER_TESTS"/></xsl:with-param>
             <xsl:with-param name="central_text"><xsl:value-of select="$pass_tests_percent"/></xsl:with-param>
             <xsl:with-param name="bottom_text"><xsl:value-of select="concat($RES_PARAMETER_TEST_FAILURES,': ',$total_fail_test_cases,'/',$total_test_cases)" /></xsl:with-param>
             <xsl:with-param name="item_names"><xsl:value-of select="$RES_PARAMETER_FAILED_TEST_CASES"/>,<xsl:value-of select="$RES_PARAMETER_TESTS"/></xsl:with-param>
             <xsl:with-param name="item_colors"><xsl:value-of 
                select="$tests_failed_color"/>,<xsl:value-of
                select="$tests_passed_color"/></xsl:with-param>
             <xsl:with-param name="item_data"><xsl:value-of
                select="$total_fail_test_cases"/>,<xsl:value-of
                select="$total_pass_test_cases"/></xsl:with-param>
             <xsl:with-param name="img_name" select="concat('unit_exc_summary_',$org_time)"/>
          </xsl:call-template>
       
          </td>

          <xsl:variable name="vals" saxon:assignable="yes" select="/ResultsSession/Exec/Coverage/CvgStats/CvgInfo/@val"/>
          <xsl:for-each select="/ResultsSession/Exec/Coverage/Types/CvgType">

          <td>
             <xsl:variable name="value" saxon:assignable="yes" select="substring-before(($vals),';')"/>
             <xsl:if test="not(string-length($value) &gt; 0)">
                <saxon:assign name="value" select="$vals"/>
             </xsl:if>
             <saxon:assign name="vals" select="substring-after(($vals),';')"/>
             
             <xsl:variable name="coverage_percent" select="concat($value,'%')"/>
              <xsl:if test="number($value) = number($value)">
                  <xsl:call-template name="generate_ring_chart">
                      <xsl:with-param name="title">
                          <xsl:value-of select="$RES_PARAMETER_COVERAGE"/>
                      </xsl:with-param>
                      <xsl:with-param name="central_text">
                          <xsl:value-of select="$coverage_percent"/>
                      </xsl:with-param>
                      <xsl:with-param name="bottom_text">
                          <xsl:value-of select="concat(@dispName,': ',$coverage_percent)"/>
                      </xsl:with-param>
                      <xsl:with-param name="item_names">Covered,Not Covered</xsl:with-param>
                      <xsl:with-param name="item_colors"><xsl:value-of
                              select="$covered_color"/>,<xsl:value-of
                              select="$not_covered_color"/>
                      </xsl:with-param>
                      <xsl:with-param name="item_data"><xsl:value-of
                              select="$value"/>,<xsl:value-of
                              select="100-$value"/>
                      </xsl:with-param>
                      <xsl:with-param name="img_name" select="concat('unit_cvg_summary_',@id,'_',$org_time)"/>
                  </xsl:call-template>
              </xsl:if>
          </td>
          </xsl:for-each>

          <xsl:if test="not($report_format_mode='pdf')">
             <td width="5%"></td>
          </xsl:if>
       </tr></table>
    </xsl:template>
        
    <!-- =================  print execution author details ============================ -->
    
    <xsl:template name="execution_author_details_info">
        <xsl:param name="auth"/>
        <xsl:param name="authid"/>
        <xsl:param name="authidx"/>
        <xsl:param name="author_exec_errors"/>
        <xsl:param name="author_exec_urgent_errors"/>

    <xsl:variable name="author_exc_history" select="count(/ResultsSession/Exec/History/Graph[@id=$exec_tasks_graph_id]/Authors/Author[@name = $auth]/X)"/>

    <!-- unit history graph -->
    <xsl:if test="($generate_graphs = 'true') and ($author_exc_history) > 0">
    <xsl:call-template name="generate_graph">
       <xsl:with-param name="graph" select="/ResultsSession/Exec/History/Graph[@id=$exec_tasks_graph_id]"/>
       <xsl:with-param name="auth" select="$auth"/>
       <xsl:with-param name="img_name" select="concat('unit_exc_',$authid,'_',$org_time)"/>
    </xsl:call-template>
    <br/>
    </xsl:if>
    <!-- unit execution legend -->
    <table width='{$width}' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>

    <tr>
    <td align="left">
    <xsl:if test="($author_exec_urgent_errors) > 0">
        <a class="black_link" href="#te_urg_{$authid}"><b><xsl:value-of select="$RES_PARAMETER_RECOMMENDED_FINDINGS_TO_ACCOMPLISH"/></b></a>:
    </xsl:if>
    <xsl:if test="not(($author_exec_urgent_errors) > 0)">
        <b><xsl:value-of select="$RES_PARAMETER_RECOMMENDED_FINDINGS_TO_ACCOMPLISH"/></b>:
    </xsl:if>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($author_exec_urgent_errors)"/>
    </td>
    </tr>
    
    <tr>
    <td align="left">
    
    <b><xsl:value-of select="$RES_PARAMETER_FINDINGS"/></b>:
    <!-- total tasks -->    
    <xsl:value-of select="($author_exec_errors)"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:if test="($report_type=$email_report) or ($author_exec_errors = $author_exec_urgent_errors)">
        <b><xsl:value-of select="$RES_PARAMETER_TOTAL_LOWERCASE"/></b>
    </xsl:if>
    <xsl:if test="($author_exec_errors > $author_exec_urgent_errors) and not($report_type=$email_report)">
        <a class="black_link" href="#te_{$auth}"><b><xsl:value-of select="$RES_PARAMETER_TOTAL_LOWERCASE"/></b></a>
    </xsl:if>

    <!-- delta total -->
    <xsl:if test="count(/ResultsSession/Exec/History/Graph[@id=$exec_tasks_graph_id]/Authors/Author) > 0">
    ,<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:call-template name="format_author_total_delta">
        <xsl:with-param name="delta" select="/ResultsSession/Exec/History/Graph[@id=$exec_tasks_graph_id]/Authors/Author[@name=($auth)]/Delta"/>
    </xsl:call-template>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
        <b><xsl:value-of select="$RES_PARAMETER_DELTA_TOTAL"/></b>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </xsl:if>
    
    </td>
    </tr>
    <xsl:if test="$goals > 0">
       <tr>
       <td align="left">
          <b><xsl:value-of select="$RES_PARAMETER_GOAL"/></b>:
            <xsl:call-template name="print_goals">
                <xsl:with-param name="violationsList" select="/ResultsSession/Exec/ExecViols/*[@auth=($auth)]"/>
            </xsl:call-template>
       </td>
       </tr>
    </xsl:if>
    </table>
    <br/>
    
    <!-- test execution recommended summary -->
    <xsl:variable name="summary_errors" select="count(/ResultsSession/Exec/Categories/CategoryGroup/Category)"/>
    <xsl:if test="($summary_errors > 0) and ($author_exec_urgent_errors > 0) ">
    <saxon:assign name="isFirstRow">true</saxon:assign>
    <xsl:call-template name="te_author_errors_summary">
    <xsl:with-param name="auth" select="($auth)"/>
    <xsl:with-param name="authidx" select="($authidx)"/>
    <xsl:with-param name="urgent">true</xsl:with-param>
    </xsl:call-template>
    <br/>
    <table width='{$width}' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">50% 25% 25%</xsl:attribute>
        </xsl:if>
    <xsl:call-template name="exec_author_details">
    <xsl:with-param name="auth" select="($auth)"/>
    <xsl:with-param name="authid" select="($authid)"/>
    <xsl:with-param name="mode">single</xsl:with-param>
    <xsl:with-param name="urgent">true</xsl:with-param>
    </xsl:call-template>
    </table>
    </xsl:if>

    <!-- test execution total summary -->
    <xsl:if test="($summary_errors > 0) and ($author_exec_errors > $author_exec_urgent_errors) and not($report_type=$email_report)">
    <saxon:assign name="isFirstRow">true</saxon:assign>
    <xsl:call-template name="te_author_errors_summary">
       <xsl:with-param name="auth" select="($auth)"/>
       <xsl:with-param name="authidx" select="($authidx)"/>
    </xsl:call-template>
    <br/>
    </xsl:if>
    <xsl:if test="(($author_exec_errors > $author_exec_urgent_errors) or not($author_exec_urgent_errors > 0)) and not($report_type=$email_report)">
    <table width='{$width}' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">50% 25% 25%</xsl:attribute>
        </xsl:if>
    <xsl:call-template name="exec_author_details">
    <xsl:with-param name="auth" select="($auth)"/>
    <xsl:with-param name="authid" select="($authid)"/>
    <xsl:with-param name="mode">single</xsl:with-param>
    </xsl:call-template>
    </table>
    </xsl:if>
    
    </xsl:template>

    <!-- =================  print execution goals data ============================ -->

    <xsl:template name="print_execution_goals_data">

        <xsl:variable name="goal_desc_none" saxon:assignable="yes"></xsl:variable>
        <xsl:variable name="goal_desc_all" saxon:assignable="yes"></xsl:variable>
        <xsl:variable name="goal_desc_suggest" saxon:assignable="yes"></xsl:variable>
    
        <xsl:for-each select="/ResultsSession/Exec/Goals/Goal">
        
            <xsl:sort select="@type"/>
            <xsl:variable name="exec_goal_mode" select="@mode"/>
            <xsl:variable name="exec_goal_date" select="@date"/>
            <xsl:variable name="exec_goal_happy" select="@happy"/>
            <xsl:variable name="exec_goal_happy_only" select="@onlyHappy"/>
            <xsl:variable name="exec_goal_name" select="@name"/>

            <!-- DON'T PERFORM FINDINGS -->
            <xsl:if test="($exec_goal_mode) = '0'">
                <xsl:if test="string-length($goal_desc_none) > 0"><saxon:assign name="goal_desc_none"> <xsl:value-of select="concat($goal_desc_none,', ')"/> </saxon:assign></xsl:if>
                <saxon:assign name="goal_desc_none"> <xsl:value-of select="concat($goal_desc_none,$exec_goal_name)"/> </saxon:assign>
            </xsl:if>
            <!-- ALL FINDINGS -->
            <xsl:if test="($exec_goal_mode) = '1'">
                <xsl:if test="string-length($goal_desc_all) > 0"><saxon:assign name="goal_desc_all"> <xsl:value-of select="concat($goal_desc_all,', ')"/> </saxon:assign></xsl:if>
                <saxon:assign name="goal_desc_all"> <xsl:value-of select="concat($goal_desc_all,$exec_goal_name)"/> </saxon:assign>
            </xsl:if>    
            <!-- SUGGEST FINDINGS -->
            <xsl:if test="($exec_goal_mode) = '2'">
                <xsl:if test="string-length($goal_desc_suggest) > 0"><saxon:assign name="goal_desc_suggest"> <xsl:value-of select="concat($goal_desc_suggest,', ')"/> </saxon:assign></xsl:if>
                <xsl:if test="not($exec_goal_happy = '0')">
                    <saxon:assign name="goal_desc_suggest" select="concat($goal_desc_suggest,$RES_PARAMETER_GOAL_NO_MORE_THAN,' &lt;b&gt;',$exec_goal_happy,'&lt;/b&gt; ',$exec_goal_name)"/>
                </xsl:if>
                <xsl:if test="$exec_goal_happy = '0'">
                    <saxon:assign name="goal_desc_suggest" select="concat($goal_desc_suggest,$RES_PARAMETER_GOAL_NO,' ',$exec_goal_name)"/>
                </xsl:if>
                <xsl:if test="not($exec_goal_happy_only = 'true') and string-length($exec_goal_date) > 0">
                    <saxon:assign name="goal_desc_suggest" select="concat($goal_desc_suggest,' ',$RES_PARAMETER_GOAL_BY,' &lt;b&gt;',$exec_goal_date,'&lt;/b&gt;')"/>
                </xsl:if>       
            </xsl:if>
                
        </xsl:for-each> 
     
        <xsl:variable name="goal_desc" saxon:assignable="yes"></xsl:variable>
        <xsl:if test="string-length($goal_desc_all) > 0">
            <saxon:assign name="goal_desc"> <xsl:value-of select="concat($RES_PARAMETER_ACCOMPLISH_ALL,' ',$goal_desc_all)"/> </saxon:assign>
        </xsl:if>   
        <xsl:if test="string-length($goal_desc_none) > 0">
            <xsl:if test="string-length($goal_desc) > 0"><saxon:assign name="goal_desc"> <xsl:value-of select="concat($goal_desc,', ')"/> </saxon:assign></xsl:if>
                <saxon:assign name="goal_desc"> <xsl:value-of select="concat($goal_desc,$RES_PARAMETER_DONT_PERFORM,' ',$goal_desc_none)"/> </saxon:assign>
            </xsl:if>   
            <xsl:if test="string-length($goal_desc_suggest) > 0">
            <xsl:if test="string-length($goal_desc) > 0"><saxon:assign name="goal_desc"> <xsl:value-of select="concat($goal_desc,', ')"/> </saxon:assign></xsl:if>
                <saxon:assign name="goal_desc"> <xsl:value-of select="concat($goal_desc,$goal_desc_suggest)"/> </saxon:assign>
            </xsl:if>   
        <xsl:if test="not(string-length($goal_desc) > 0)">
            <saxon:assign name="goal_desc"> <xsl:value-of select="$RES_PARAMETER_ACCOMPLISH_ALL_FINDINGS"/> </saxon:assign>
        </xsl:if>   
        <xsl:value-of select="($goal_desc)" disable-output-escaping="yes"/>
    
    </xsl:template>
    

    <!-- =================  print execution summary statistics ============= -->
    
    <xsl:template name="exec_summary_stats">
       <xsl:param name="auth"/>

       <xsl:variable name="label" saxon:assignable="yes"></xsl:variable>
       
       <xsl:if test="string-length($auth) > 0">
       
          <xsl:variable name="author_exec_violations" 
             select="count(/ResultsSession/Exec/ExecViols/*[@auth=($auth)])"/>
              
          <xsl:variable name="author_exec_recommended_violations" 
             select="count(/ResultsSession/Exec/ExecViols/*[@auth=($auth) and @urgent='true'])"/>

          <!--xsl:if test="not(($author_exec_recommended_violations) > 0)">
             <saxon:assign name="label" select="concat($RES_PARAMETER_TOTAL_FINDINGS,': ',$author_exec_violations)"/>
          </xsl:if>    
          <xsl:if test="($author_exec_recommended_violations) > 0"-->
             <saxon:assign name="label" select="concat($RES_PARAMETER_RECOMMENDED_FINDINGS,': ',$author_exec_recommended_violations)"/>
          <!--/xsl:if-->
       </xsl:if>    
       
       <xsl:if test="string-length($auth) = 0">
          <xsl:variable name="total_test_cases" select="sum(/ResultsSession/Exec/Projects/Project/@total)"/>
          <xsl:variable name="total_fail_test_cases" select="sum(/ResultsSession/Exec/Projects/Project/@fail)"/>
    
          <saxon:assign name="label" select="concat($RES_PARAMETER_TEST_FAILURES,': ',$total_fail_test_cases,'/',$total_test_cases)"/>
       </xsl:if>

       <xsl:value-of select="$label"/>

    </xsl:template>
    
    <!-- =================  print execution summary errors ============================ -->
    
    <xsl:template name="exec_summary">

    <xsl:variable name="tasks_type_count" select="count(/ResultsSession/Exec/Categories/CategoryGroup)"/>
    <xsl:variable name="cvg_type_count" select="count(/ResultsSession/Exec/Coverage/Types/CvgType)"/>

    <xsl:variable name="prj_with_error" select="count(/ResultsSession/Exec/Projects/Project/@err)"/>  
    <xsl:variable name="error_mode_enabled" saxon:assignable="yes">false</xsl:variable>
    <xsl:variable name="exec_test_colspan" saxon:assignable="yes">3</xsl:variable>
    <xsl:if test="($prj_with_error) > '0'">
       <saxon:assign name="error_mode_enabled">true</saxon:assign>
       <saxon:assign name="exec_test_colspan">4</saxon:assign>
    </xsl:if>

    <table width='{$width}' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>
    <tr valign="top">
    <td width="80%">
    <table class="singleborder" width='100%' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:variable name="required_colspan" select="$tasks_type_count + $exec_test_colspan + $cvg_type_count"/>  
            <xsl:if test="($required_colspan) = 3">
                <xsl:attribute name="cols">40% 20% 20% 20%</xsl:attribute>
            </xsl:if>                                          
            <xsl:if test="($required_colspan) = 4">
                <xsl:attribute name="cols">40% 21% 13% 13% 13%</xsl:attribute>
            </xsl:if>
            <xsl:if test="($required_colspan) = 5">
                <xsl:attribute name="cols">40% 15% 15% 10% 10% 10%</xsl:attribute>
            </xsl:if>
            <xsl:if test="($required_colspan) = 6">
                <xsl:attribute name="cols">40% 10% 10% 10% 10% 10% 10%</xsl:attribute>
            </xsl:if>
            <xsl:if test="($required_colspan) = 7">
                <xsl:attribute name="cols">30% 10% 10% 10% 10% 10% 10% 10%</xsl:attribute>
            </xsl:if>
            <xsl:if test="($required_colspan) = 8">
                <xsl:attribute name="cols">30% 9% 9% 9% 9% 9% 8% 9% 8%</xsl:attribute>
            </xsl:if>
            <xsl:if test="($required_colspan) = 9">
                <xsl:attribute name="cols">30% 8% 8% 8% 8% 8% 8% 7% 8% 7%</xsl:attribute>
            </xsl:if>
            <xsl:if test="($required_colspan) = 10">
                <xsl:attribute name="cols">25% 8% 8% 8% 8% 8% 7% 7% 7% 7% 7%</xsl:attribute>
            </xsl:if>
            <xsl:if test="($required_colspan) = 11">
                <xsl:attribute name="cols">25% 7% 7% 7% 7% 7% 7% 7% 7% 7% 6% 6%</xsl:attribute>
            </xsl:if>
            <xsl:if test="($required_colspan) = 12">
                <xsl:attribute name="cols">20% 7% 7% 7% 7% 7% 7% 7% 7% 6% 6% 6% 6%</xsl:attribute>
            </xsl:if>
            <xsl:if test="($required_colspan) = 13">
                <xsl:attribute name="cols">20% 7% 7% 6% 6% 6% 6% 6% 6% 6% 6% 6% 6% 6%</xsl:attribute>
            </xsl:if>
        </xsl:if>
        
    <tr>
    <td class="singleborder right_separator" width="40%" align='center' bgcolor="{$exec_bcolor}">
        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><b><xsl:value-of select="$RES_PARAMETER_MODULE"/></b><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><br/></td>
    <xsl:if test="($tasks_type_count) > 0">
    <td class="singleborder" align='center' colspan='{$tasks_type_count}' bgcolor="{$exec_bcolor}">
        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><b><xsl:value-of select="$RES_PARAMETER_FINDINGS"/></b><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><br/></td>
    </xsl:if>
    <td class="singleborder right_separator left_separator" align='center' colspan="{$exec_test_colspan}" bgcolor="{$exec_bcolor}">
        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><b><xsl:value-of select="$RES_PARAMETER_EXECUTED_TEST_CASES"/></b><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><br/></td>
        
    <xsl:if test="($cvg_type_count) > 0">
    <td class="singleborder" align='center' colspan="{$cvg_type_count}" bgcolor="{$exec_bcolor}">
        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><b><xsl:value-of select="$RES_PARAMETER_COVERAGE_HEADER"/> (%)</b><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><br/></td>
    </xsl:if>
    </tr>
    
    <tr>    
      <td class="singleborder right_separator" align='center' bgcolor="{$exec_bcolor}">
      <span style="zoom:1;"/>
      </td>
       <xsl:for-each select="/ResultsSession/Exec/Categories/CategoryGroup">
          <td class="singleborder" align='center' bgcolor="{$exec_bcolor}">
             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="textutil:lowercase(@label)"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
          </td>
       </xsl:for-each>
       
       <td class="singleborder left_separator" align='center' bgcolor="{$exec_bcolor}">
          <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="$RES_PARAMETER_PASSED_TEST_CASES_LOWERCASE"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
       </td>
       <td class="singleborder" align='center' bgcolor="{$exec_bcolor}">
          <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="$RES_PARAMETER_FAILED_TEST_CASES_LOWERCASE"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
       </td>
       <xsl:if test="($error_mode_enabled = 'true')">           
         <td class="singleborder" align='center' bgcolor="{$exec_bcolor}">
             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="$RES_PARAMETER_INCOMPLETE_TEST_CASES_LOWERCASE"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
          </td>
       </xsl:if>
       <td class="singleborder right_separator" align='center' bgcolor="{$exec_bcolor}">
          <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="$RES_PARAMETER_TOTAL_LOWERCASE"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
       </td>
       <xsl:for-each select="/ResultsSession/Exec/Coverage/Types/CvgType">
          <td class="singleborder" align='center' bgcolor="{$exec_bcolor}">
             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="textutil:lowercase(@dispId)"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
          </td>
       </xsl:for-each>
    </tr>
    
    <xsl:variable name="total_time" select="/ResultsSession/Exec/@time"/>
    
    <xsl:variable name="total_test_cases" select="sum(/ResultsSession/Exec/Projects/Project/@total)"/>
    <xsl:variable name="total_pass_test_cases" select="sum(/ResultsSession/Exec/Projects/Project/@pass)"/>
    <xsl:variable name="total_fail_test_cases" select="sum(/ResultsSession/Exec/Projects/Project/@fail)"/>
    <xsl:variable name="total_err_test_cases" select="sum(/ResultsSession/Exec/Projects/Project/@err)"/>

    <xsl:for-each select="/ResultsSession/Exec/Projects/Project">
       <xsl:sort select="@name"/>
       <xsl:variable name="project_name" select="@name"/>
       <xsl:variable name="currProject" select="."/>
    
       <tr class="alternating">
       <xsl:if test="(@fail > 0) or (@err > 0)">
              <xsl:attribute name="class">errorsingleborder</xsl:attribute>
       </xsl:if>
       <!-- project name -->
       <td class="singleborder right_separator" align="left">
		   <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="($project_name)"/>
	   </td>       
       
       
       <xsl:for-each select="/ResultsSession/Exec/Categories/CategoryGroup">

          <xsl:variable name="currCategory" select="@id"/>
          <xsl:variable name="currCategoryErrorsCount" select="sum($currProject/CategoryGroupStats[@id=$currCategory]/@total)"/>
          <td class="singleborder" align="center">  
             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
             <xsl:value-of select="($currCategoryErrorsCount)"/> 
             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
          </td> 
       </xsl:for-each>
       
       <!-- passed test cases -->
       <td class="singleborder left_separator" align="center">  
          <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
          <xsl:value-of select="@pass"/>
          <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
       </td>
       <!-- failed test cases -->
       <td class="singleborder" align="center">  
          <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
          <xsl:value-of select="@fail"/>
          <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
       </td>

       <xsl:if test="($error_mode_enabled = 'true')">           
          <!-- error test cases -->
          <td class="singleborder" align="center">  
             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
             <xsl:value-of select="@err"/>
             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
          </td>
       </xsl:if>
       
       <!-- test cases -->
       <td class="singleborder right_separator" align="center">  
          <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
          <xsl:value-of select="@total"/> 
          <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
       </td>
       
       <!--  coverage -->
       <xsl:variable name="cvgElem" select="/ResultsSession/Exec/Coverage/CvgStats/CvgInfo/CvgInfo[@elem=$project_name]"/>
       <xsl:call-template name="coverage_table_items">
          <xsl:with-param name="cvgElem" select="($cvgElem)"/>
          <xsl:with-param name="boldItem">false</xsl:with-param>
       </xsl:call-template>   
       </tr>
    </xsl:for-each>
    
    <tr>
    <td class="singleborder right_separator" align="left" bgcolor="{$exec_bcolor}">
       <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
       <b><xsl:value-of select="$RES_PARAMETER_TOTAL"/></b> [<xsl:value-of select="($total_time)"/>]
    </td>
    <xsl:for-each select="/ResultsSession/Exec/Categories/CategoryGroup">

       <xsl:variable name="currCategory" select="@id"/>
       <xsl:variable name="currCategoryErrorsCount" select="sum(/ResultsSession/Exec/Projects/Project/CategoryGroupStats[@id=$currCategory]/@total)"/>
       <td class="singleborder" align="center" bgcolor="{$exec_bcolor}">  
          <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
          <xsl:value-of select="($currCategoryErrorsCount)"/> 
          <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
       </td> 
    </xsl:for-each>
    
    <!-- total passed test cases -->
    <td class="singleborder left_separator" align="center" bgcolor="{$exec_bcolor}">  
       <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
       <b><xsl:value-of select="($total_pass_test_cases)"/></b> 
       <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>
    <!-- total failed test cases -->
    <td class="singleborder" align="center" bgcolor="{$exec_bcolor}">  
       <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
       <b><xsl:value-of select="($total_fail_test_cases)"/></b>
       <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>
    
    <xsl:if test="($error_mode_enabled = 'true')">           
       <!-- total errror test cases -->
       <td class="singleborder" align="center" bgcolor="{$exec_bcolor}">  
          <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
          <b><xsl:value-of select="($total_err_test_cases)"/></b>
          <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
       </td>
    </xsl:if>
    
    <!-- total test cases -->
    <td class="singleborder right_separator" align="center" bgcolor="{$exec_bcolor}">  
       <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
       <b><xsl:value-of select="($total_test_cases)"/></b> 
       <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>
    
    <!-- coverage -->
    <xsl:variable name="cvgElem" select="/ResultsSession/Exec/Coverage/CvgStats/CvgInfo"/>
    <xsl:call-template name="coverage_table_items">
       <xsl:with-param name="cvgElem" select="($cvgElem)"/>
       <xsl:with-param name="boldItem">true</xsl:with-param>
    </xsl:call-template>
    
    </tr>
    
    </table>
    </td>   
    </tr>    
    <tr>
    <td width="80%" align="left">
    <table width='100%' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">           
            <xsl:attribute name="cols">10% 90%</xsl:attribute>            
        </xsl:if>
    <xsl:if test="not($report.mail.compact = $trends) or not(($report_type) = ($email_report))">
    <tr>
    <td colspan='2'>
    <br/>
    
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><b><xsl:value-of select="$RES_PARAMETER_LEGEND"/></b>
    <br/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>
    </tr>
    <tr><td nowrap="nowrap"><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td><td>
    <table width='100%' cellpadding='2' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">35% 5% 60%</xsl:attribute>
        </xsl:if>
    <tr valign="top">    
    <td nowrap="nowrap"><b><xsl:value-of select="$RES_PARAMETER_MODULE"/></b><br/></td>
    <td>-</td>
    <td><xsl:value-of select="$RES_PARAMETER_TEST_MODULE_DESC"/><br/></td>
    </tr>
    
    <xsl:for-each select="/ResultsSession/Exec/Categories/CategoryGroup">
       <xsl:if test="string-length(@desc)> 0">
       <tr valign="top">
          <td nowrap="nowrap"><b><xsl:value-of select="@label"/></b><br/></td>
          <td>-</td>
          <td><xsl:value-of select="@desc"/><br/></td>
       </tr>
       </xsl:if>
    </xsl:for-each>
    
    <xsl:for-each select="/ResultsSession/Exec/Coverage/Types/CvgType">
       <xsl:if test="string-length(@dispName) &gt; 0">
       <tr valign="top">
          <td nowrap="nowrap"><b><xsl:value-of select="@dispId"/></b><br/></td>
          <td>-</td>
          <td><xsl:value-of select="@dispName"/><br/></td>
       </tr>
       </xsl:if>
    </xsl:for-each>
    
    </table>
    </td></tr> 
	</xsl:if>  
    </table>
    </td>
    </tr>
    
    <!-- display leak bytes -->
    
    <xsl:variable name="leak_bytes" select="sum(/ResultsSession/Exec/ExecViols/InsureViol[@cat=$subCategoryId_LeakSummary]/@lBytes)"/>    
    <xsl:if test="($leak_bytes) > 0">	   
    <tr>
    <td><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/></td>
    </tr>
    <tr>
    <td>
    <table class="singleborder" width='100%' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">34% 33% 33%</xsl:attribute>
        </xsl:if>
    <tr>
    <td class="singleborder" align='center' bgcolor="{$exec_bcolor}" colspan='3'>
        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><b><xsl:value-of select="$RES_PARAMETER_MEMORY_LEAK_SUMMARY"/></b><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><br/></td>
    </tr>
    <tr>
    <td class="singleborder" align='center' width="34%" bgcolor="{$exec_bcolor}"><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><b>PID</b></td>
    <td class="singleborder" align='center' width="33%" bgcolor="{$exec_bcolor}"><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><b>Amount</b></td>
    <td class="singleborder" align='center' width="33%" bgcolor="{$exec_bcolor}"><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><b>Chunks</b></td>
    </tr>
    <xsl:for-each select="saxon:distinct(/ResultsSession/Exec/ExecViols/InsureViol/@pid)">
    <xsl:variable name="runtimePid" select="."/>
    <xsl:variable name="leakBytes" select="sum(/ResultsSession/Exec/ExecViols/InsureViol[@pid=$runtimePid]/@lBytes)"/>
    <xsl:variable name="leakChunks" select="sum(/ResultsSession/Exec/ExecViols/InsureViol[@pid=$runtimePid]/@lChunks)"/>
    <xsl:variable name="leakKbytes" select="round(($leakBytes) div 1024)"/>
    <xsl:if test="($leakBytes) > 0">	   
    <tr>
    <td class="singleborder" width="34%"><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="$runtimePid"/></td>
    <td class="singleborder" align="center" width="33%">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($leakBytes)"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    bytes
    <xsl:if test="($leakKbytes) > 0">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    (<xsl:value-of select="($leakKbytes)"/>K)
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </xsl:if>
    </td>
    <td class="singleborder" align="center" width="33%">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($leakChunks)"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>
    </tr>
    </xsl:if>
    </xsl:for-each>
    </table>
    </td>
    </tr>
    </xsl:if>	    
    </table>
    </xsl:template>


    <!-- =================  coverage_table_items ============================ -->
    
    <xsl:template name="coverage_table_items">
    <xsl:param name="cvgElem"/>
    <xsl:param name="boldItem"/>

       <xsl:variable name="vals" saxon:assignable="yes" select="$cvgElem/@val"/>
       <xsl:for-each select="/ResultsSession/Exec/Coverage/Types/CvgType">

          
		  <xsl:element name="td">          
		  	<xsl:attribute name="class">singleborder</xsl:attribute>
		  	<xsl:attribute name="align">center</xsl:attribute>		  	
          	<xsl:if test="($boldItem = 'true')">
          		<xsl:attribute name="bgcolor"><xsl:value-of select="$exec_bcolor" /></xsl:attribute>
          		</xsl:if>          	          	  
             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>

             <xsl:variable name="value" saxon:assignable="yes" select="substring-before(($vals),';')"/>
             <xsl:if test="not(string-length($value) &gt; 0)">
                <saxon:assign name="value" select="$vals"/>
             </xsl:if>
             <saxon:assign name="vals" select="substring-after(($vals),';')"/>
             
             <xsl:if test="($boldItem = 'true')"><b><xsl:value-of select="($value)"/></b></xsl:if>
             <xsl:if test="not($boldItem = 'true')"><xsl:value-of select="($value)"/></xsl:if>

             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
          </xsl:element> 
       </xsl:for-each>
    </xsl:template>

    <!-- =================  te_summary_title ============================ -->
    
    <xsl:template name="te_summary_title">
    <xsl:param name="urgent"/>
    <tr>
    <td>
    <table class="header" width="100%" cellpadding="0" cellspacing="0">
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>
    <tr>
    <td align='center'>
    <xsl:if test="not($urgent = 'true')">
        <div class="small_header"><xsl:value-of select="$RES_PARAMETER_DISTRIBUTION_TOTAL"/></div>
    </xsl:if>
    <xsl:if test="($urgent = 'true')">
        <div class="small_header"><xsl:value-of select="$RES_PARAMETER_DISTRIBUTION_RECOMMENDED"/></div>
    </xsl:if>
    </td>
    </tr>
    </table>
    </td>
    </tr>
    </xsl:template>
    
    <!-- =================  print test execution error summary ============================ -->
    
    <xsl:template name="te_error">
    <xsl:param name="name"/>
    <xsl:param name="total"/>
    <xsl:param name="level"/>
    <xsl:if test="($total) &gt; 0">

    <xsl:variable name="rowStyle" saxon:assignable="yes">tree</xsl:variable>
    <!--xsl:if test="$isFirstRow = 'true'">
        <saxon:assign name="rowStyle">root</saxon:assign>
        <saxon:assign name="isFirstRow" select="false"/>
    </xsl:if-->
    <xsl:if test="($level = '1')">
    <tr><td>
        <xsl:call-template name="print_header_separator"/>
    </td></tr>
    </xsl:if>
    <tr><td class="{$rowStyle}">

    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:if test="($level = '2') or ($level = '3')">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </xsl:if>
    <xsl:if test="($level = '3')">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </xsl:if>
    [<b><xsl:value-of select="($total)"/></b>]
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:if test="($level = '1') or ($level = '2')">
    <b><xsl:value-of select="($name)"/></b>
    </xsl:if>
    <xsl:if test="$level = '3'">
    <xsl:value-of select="($name)"/>
    </xsl:if>
    </td>
    </tr>
    </xsl:if>
    </xsl:template>
    
    <!-- =================  te_error_summary  ============================ -->
    
    <xsl:template name="te_error_summary">

    <xsl:for-each select="/ResultsSession/Exec/Categories/CategoryGroup">
       <xsl:variable name="currCategory" select="@id"/>
       <xsl:variable name="currCategoryErrorsCount" select="sum(./@total)"/>
       <xsl:if test="($currCategoryErrorsCount) > 0">
       
          <xsl:call-template name="te_error">
             <xsl:with-param name="name"><xsl:value-of select="@name"/></xsl:with-param>
             <xsl:with-param name="total" select="$currCategoryErrorsCount"/>
             <xsl:with-param name="level">1</xsl:with-param>
          </xsl:call-template>
          
          <xsl:for-each select="./Category">
             <xsl:variable name="currSubCategory" select="@id"/>
             <xsl:variable name="currSubCategoryErrorsCount" select="sum(./@total)"/>
             <xsl:call-template name="te_subcategory_summary">
                <xsl:with-param name="category_name"><xsl:value-of select="@name"/></xsl:with-param>
                <xsl:with-param name="cat"><xsl:value-of select="@id"/></xsl:with-param>
                <xsl:with-param name="total" select="($currSubCategoryErrorsCount)"/>
             </xsl:call-template>
          </xsl:for-each>
          
       </xsl:if>
    </xsl:for-each>

    </xsl:template>
    
    <!-- =================  te_subcategory_summary  ============================ -->
    
    <xsl:template name="te_subcategory_summary">
    <xsl:param name="cat"/>
    <xsl:param name="category_name"/>
    <xsl:param name="total"/>
    <xsl:if test="($total) > 0">
    <xsl:call-template name="te_error">
    <xsl:with-param name="name" select="$category_name"/>
    <xsl:with-param name="total" select="($total)"/>
    <xsl:with-param name="level">2</xsl:with-param>
    </xsl:call-template>
    <xsl:for-each select="/ResultsSession/Exec/Categories/CategoryGroup/Category[@id=$cat]/Type">
    <xsl:call-template name="te_error">
    <xsl:with-param name="name" select="@name"/>
    <xsl:with-param name="total" select="@total"/>
    <xsl:with-param name="level">3</xsl:with-param>
    </xsl:call-template>
    </xsl:for-each>
    </xsl:if>
    </xsl:template>
    
    <!-- =================  te_errors_summary  ============================ -->
    
    <xsl:template name="te_errors_summary">
    <table width='100%' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>
    <xsl:call-template name="te_summary_title"/>
    <tr>
    <td align="left">
    <table width='100%' class="doubleborder" cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>
    <saxon:assign name="isFirstRow">true</saxon:assign>
    <xsl:call-template name="te_error_summary"/>
    </table>
    </td>
    </tr>
    </table>
    </xsl:template>
    
    <!-- ================= execution errors summary ============================ -->
    
    <xsl:template name="exec_errors_summary">
    <xsl:variable name="summary_errors" select="count(/ResultsSession/Exec/Projects/Project/CategoryGroupStats)"/>
    <xsl:if test="($summary_errors) > 0">
    <table width='{$width}' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>
    <tr>
    <td>
    <xsl:call-template name="te_errors_summary"/>
    </td>
    </tr>
    </table>
    </xsl:if>
    </xsl:template>

    <!-- =================  print execution auth info ============================ -->
    
    <xsl:template name="exec_author_info">
    <xsl:param name="auth"/>
    <xsl:param name="authid"/>

    <xsl:variable name="author_cs_violations" 
        select="count(/ResultsSession/CodingStandards/StdViols/*[@auth=($auth) and not(@supp='true')])"/>
    <xsl:variable name="author_cs_supp" 
        select="count(/ResultsSession/CodingStandards/StdViols/*[@auth=($auth) and @supp='true'])"/>
    <xsl:variable name="author_tcases" 
        select="count(/ResultsSession/Generation/GenerationInformations/GenerationInfo[@auth=($auth)]/TestCaseList/TestCase)"/>
    <xsl:variable name="author_exec_violations" 
	    select="count(/ResultsSession/Exec/ExecViols/*[@auth=($auth)])"/>
    <xsl:variable name="enable_supp" saxon:assignable="yes">0</xsl:variable>
    <xsl:if test="($report.suppressed_msgs = 'true') and (($author_cs_supp) > 0)">
    <saxon:assign name="enable_supp">1</saxon:assign>
    </xsl:if>
    <xsl:variable name="author_all_tasks" select="($author_cs_violations) + ($author_tcases) + ($author_exec_violations) + ($enable_supp)"/>    
    <xsl:variable name="author_exec_recommended_violations" 
                 select="count(/ResultsSession/Exec/ExecViols/*[@auth=($auth) and @urgent='true'])"/>
    <tr class="alternating">
    <td class="singleborder right_separator" align="left">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>

    <xsl:variable name="link_class" saxon:assignable="yes">blue_link</xsl:variable>
    <xsl:variable name="font_class" saxon:assignable="yes">black</xsl:variable>
       
    <!--xsl:if test="($author_exec_recommended_violations = 0)">
    <saxon:assign name="link_class">green_link</saxon:assign>
    <saxon:assign name="font_class">green</saxon:assign>
    </xsl:if-->

    <xsl:call-template name="exec_author_link">
        <xsl:with-param name="auth" select="($auth)"/>
        <xsl:with-param name="authid" select="($authid)"/>
	<xsl:with-param name="link_class" select="($link_class)"/>
	<xsl:with-param name="font_class" select="($font_class)"/>
	<xsl:with-param name="has_tasks" select="boolean(($author_all_tasks) > 0)"/>
    </xsl:call-template>

    </td>
    <xsl:if test="count(/ResultsSession/Exec/History/Graph[@id=$exec_tasks_graph_id]/Authors/Author) > 0">
    <td class="singleborder" align="center">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    
    <xsl:call-template name="format_author_total_delta">
        <xsl:with-param name="delta" select="/ResultsSession/Exec/History/Graph[@id=$exec_tasks_graph_id]/Authors/Author[@name=($auth)]/Delta"/>
    </xsl:call-template>
    
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>   
    </xsl:if>
    <td class="singleborder" align="center">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($author_exec_violations)"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>   
    <td class="singleborder" align="center">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($author_exec_recommended_violations)"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>   
    </tr>
    <!-- TODO remove? /xsl:if -->
    </xsl:template>
    
    <!-- =================  print execution auth link ============================ -->

    <xsl:template name="exec_author_link">
    <xsl:param name="auth"/>
    <xsl:param name="authid"/>
    <xsl:param name="link_class"/>
    <xsl:param name="font_class"/>
    <xsl:param name="has_tasks"/>

    <xsl:if test="($has_tasks='true')">

    <xsl:if test="(($report.developer_reports) = 'true') and (not(($report_type) = ($email_report)) or ($report_format_mode='pdf'))">
    <xsl:variable name="author_html" select="concat($dev_reports_prefix,$authid,'.html#tet_',$authid)"/>
    <xsl:variable name="href" saxon:assignable="yes" select="concat('javascript:openWin(',$qt,$author_html,$qt,')')"/>
    <xsl:if test="($report_type) = ($tcm_report)">
       <xsl:variable name="dev_rep_name" select="concat($dev_reports_prefix,$authid,'.html')"/>
       <saxon:assign name="href" select="concat('javascript:openDevReport(',$qt,$dev_rep_name,$qt,')')"/>
    </xsl:if>
    <xsl:call-template name="standard_link_ref">
    <xsl:with-param name="href" select="($href)"/>
    <xsl:with-param name="label" select="($auth)"/>
    <xsl:with-param name="class" select="($link_class)"/>
    </xsl:call-template>
    </xsl:if>

        <xsl:if test="(($report.developer_errors) = 'true') and ((($report.developer_reports) = 'false') or ((($report_type) = ($email_report)) and not($report_format_mode='pdf')))">
    <a class="{$link_class}" href="#te_{$authid}">
    <xsl:value-of select="($auth)"/>
    </a>
    </xsl:if>

     <xsl:if test="(($report.developer_errors) = 'false') and (($report.developer_reports = 'false') or ((($report_type) = ($email_report)) and not($report_format_mode='pdf')))">
    <font class="{$font_class}">
    <xsl:value-of select="($auth)"/>
    </font>
    </xsl:if>
    </xsl:if>
    <xsl:if test="not($has_tasks='true')">
    <font class="{$font_class}">
    <xsl:value-of select="($auth)"/>
    </font>
    </xsl:if>
    
    </xsl:template>

    <!-- =================  print execution auth list ============================ -->
    
    <xsl:template name="exec_author_list">    
        <xsl:for-each select="/ResultsSession/Authors/Author">
        
            <xsl:call-template name="exec_author_info">
                <xsl:with-param name="auth" select="@name"/>
                <xsl:with-param name="authid" select="@id"/>
            </xsl:call-template>
            
       </xsl:for-each> 
    </xsl:template>
    
    <!-- =================  te_authors_summary ============================ -->
    
    <xsl:template name="te_authors_summary">
    
    <xsl:variable name="author_exec_tasks_history" select="count(/ResultsSession/Exec/History/Graph[@id=$exec_tasks_graph_id]/Authors/Author)"/>
    
    <xsl:call-template name="authors_header"/>
    
    <table align="center" class="singleborder" width='{$authors_width}' cellpadding='0' cellspacing='0'>
    <xsl:if test="($report_format_mode='pdf')">
        <xsl:if test="$author_exec_tasks_history > 0">
            <xsl:attribute name="cols">52% 16% 16% 16%</xsl:attribute>
        </xsl:if>
        <xsl:if test="$author_exec_tasks_history = 0">
            <xsl:attribute name="cols">50% 25% 25%</xsl:attribute>            
        </xsl:if>
        
    </xsl:if>
    <tr align="center"  bgcolor="{$exec_bcolor}">
    <td class="singleborder right_separator" width="70%" align="center">
        <b><xsl:value-of select="$RES_PARAMETER_AUTHOR"/></b>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>
    <td class="singleborder" align='center'>
        <xsl:if test="$author_exec_tasks_history > 0">
            <xsl:attribute name="colspan">3</xsl:attribute>
        </xsl:if>
        <xsl:if test="$author_exec_tasks_history = 0">
            <xsl:attribute name="colspan">2</xsl:attribute>            
        </xsl:if>
        <b><xsl:value-of select="$RES_PARAMETER_FINDINGS"/></b>
    </td>
    </tr>
    
    <tr align="center"  bgcolor="{$exec_bcolor}">
    <td class="singleborder right_separator" >
	<span style="zoom:1;"/>
    </td>
	<xsl:if test="$author_exec_tasks_history > 0">
    	<td class="singleborder" align="center">
        	<xsl:value-of select="$RES_PARAMETER_DELTA_TOTAL"/>
        </td>
    </xsl:if>       
    <td class="singleborder" align="center">
        <xsl:value-of select="$RES_PARAMETER_TOTAL_LOWERCASE"/>
    </td>
    <td class="singleborder" align="center">
        <xsl:value-of select="$RES_PARAMETER_RECOMMENDED"/>
    </td>
    </tr>
    <xsl:call-template name="exec_author_list"/>
    </table>
    </xsl:template>
    
    <!-- =================  print stack trace ============================ -->
        
    <xsl:template name="stack_trace">
    <xsl:variable name="top_thr" saxon:assignable="yes">true</xsl:variable>
    <xsl:for-each select="Thr/ThrPart">
    <xsl:sort select="position()" data-type="number" order="descending"/>
    <xsl:if test="not(($top_thr) = 'true')">
    <tr>
    <td colspan="2" class="tree">
        <xsl:value-of select="$RES_PARAMETER_CAUSED_BY"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="concat(@type,': ',@msg)"/>
    </td>
    </tr>
    <saxon:assign name="globalIndex" select="$globalIndex+ 1"/>
    </xsl:if>
    <xsl:if test="($top_thr) = 'true'">
    <saxon:assign name="top_thr">false</saxon:assign>
    </xsl:if>
    <xsl:for-each select="PathElem">
    <xsl:variable name="desc" select="@desc"/>
    
    <xsl:variable name="lastSeparatorIdx" saxon:assignable="yes" select="textutil:lastIndexOf(@loc,'/')"/>    
    <xsl:variable name="loc" saxon:assignable="yes" select="@loc"/>
    <xsl:if test="($lastSeparatorIdx) > -1">
        <saxon:assign name="loc" select="substring((@loc),($lastSeparatorIdx + 2))"/>
    </xsl:if>     
    <xsl:variable name="ln" select="@ln" saxon:assignable="yes"/>    
    <xsl:if test="string-length(@startLn) > 0">
        <saxon:assign name="ln" select="@startLn"/>
    </xsl:if>     
    
    <tr><td colspan="3" class="tree">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="$desc"/>
    <!-- xsl:value-of select="concat($desc,'(',$loc,':',$ln,')')"/-->
    </td></tr>
    <saxon:assign name="globalIndex" select="$globalIndex+ 1"/>
    </xsl:for-each>
    </xsl:for-each>
    </xsl:template>

    <!-- =================  execution error details ============================ -->
    
    <xsl:template name="exec_error_details">
    <xsl:param name="errorsList"/>
    <xsl:param name="urgent"/>
    <xsl:param name="simpleMode"/>
    <xsl:param name="authorInfo"/>
    
    <xsl:variable name="tmp_file_name" select="empty" saxon:assignable="yes"/>

    <!-- xsl:for-each select="/ResultsSession/Exec/ExecViols/*[@auth=($auth)]"-->
    <xsl:for-each select="$errorsList">
    <xsl:variable name="fileName" select="@resFile" saxon:assignable="yes"/>    
    <xsl:if test="string-length(@loc) > 0">
        <saxon:assign name="fileName" select="@loc"/>
    </xsl:if>     
    <xsl:if test="string-length(@uri) > 0">
        <saxon:assign name="fileName" select="@uri"/>
    </xsl:if>     

    <xsl:variable name="testName" saxon:assignable="yes"/>
    <xsl:variable name="testCaseId" select="@tcId"/>
    <xsl:if test="string-length($testCaseId) > 0">
       <saxon:assign name="testName" select="/ResultsSession/Exec/ExecutedTestsDetails/Total/Project//TestSuite/Test/TestCase[@id=$testCaseId]/@name"/>
    </xsl:if>
    <xsl:if test="string-length($testName) = 0">
       <xsl:variable name="testId" select="@testId"/>
       <saxon:assign name="testName" select="/ResultsSession/Exec/ExecutedTestsDetails/Total/Project//TestSuite/Test[@id=$testId]/@name"/>
    </xsl:if>
    
    <xsl:variable name="cat" select="@cat"/>
    <!-- Exclude unverified outcomes? -->
    <!--xsl:if test="not(($cat) = '6') and not(($cat) = '7')"-->
    <xsl:variable name="urgent_err" select="@urgent"/>
    <xsl:if test="($urgent = 'true' and $urgent_err = 'true') or not($urgent = 'true')">
    <xsl:if test="not($tmp_file_name = $fileName)">

    <xsl:variable name="errors_count" saxon:assignable="yes">0</xsl:variable>
    <xsl:if test="not($urgent = 'true')">
    <!-- saxon:assign name="errors_count" select="count(/ResultsSession/Exec/ExecViols/*[@auth=($auth) and (@loc=($fileName) or @uri=($fileName))])"/-->
    <saxon:assign name="errors_count" select="count($errorsList[(@loc=($fileName) or @uri=($fileName))])"/>
    </xsl:if>
    <xsl:if test="$urgent = 'true'">
    <!-- saxon:assign name="errors_count" select="count(/ResultsSession/Exec/ExecViols/*[@auth=($auth) and @urgent='true' and (@loc=($fileName) or @uri=($fileName))])"/-->
    <saxon:assign name="errors_count" select="count($errorsList[@urgent='true' and (@loc=($fileName) or @uri=($fileName))])"/>
    </xsl:if>

    <xsl:if test="$simpleMode = 'false'">    
       <tr>          
          <td style="padding-left:5px;padding-right:5px;" colspan="3" class="tree">
          <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
          <b><xsl:value-of select="($fileName)"/></b>
          [ <b><xsl:value-of select="($errors_count)"/></b> ]
          </td>
       </tr>
    </xsl:if>
    
    </xsl:if>
    <xsl:choose>
    <xsl:when test="string-length(@errTypeId) > 0">
        <xsl:call-template name="insure_error_details">
            <xsl:with-param name="urgent" select="($urgent)"/>
            <xsl:with-param name="simpleMode" select="($simpleMode)"/>                        
        </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>    

    <xsl:variable name="msg" select="@msg" saxon:assignable="yes"/>
    <xsl:if test="string-length($msg) = 0">
        <saxon:assign name="msg" select="Thr/ThrPart[last()]/@msg"/>
    </xsl:if>

    <xsl:variable name="verifBy" select="@verifBy"/>
    <xsl:variable name="testParams" select="@testParams"/>
    <xsl:variable name="rev" select="@rev"/>
    
    <xsl:if test="$simpleMode = 'false' and string-length($testName) > 0">    
    <tr>
    <td style="padding-left:5px;padding-right:5px;" colspan="3" class="tree">
        <xsl:value-of select="$RES_PARAMETER_TEST_CASE"/><xsl:value-of select="($testName)"/>
    </td>           
    </tr>      
    </xsl:if>
    
    <xsl:if test="($simpleMode = 'false')">
    <xsl:if test="(($report.associations = 'true') and (count(./assoc) > 0))">    
		    <tr><td style="padding-left:5px;padding-right:5px;" colspan="3" class="tree">
        	<xsl:call-template name="associations_line"/>
        	</td></tr>
	</xsl:if>	
    </xsl:if>
    <tr>
    <td style="padding-left:5px;" colspan="2" class="tree">    
    <xsl:value-of select="($msg)" disable-output-escaping="no"/>
    <xsl:if test="(string-length($rev) > 0) and not($rev = 'unknown.revision')">
        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
        <font class="gray"><xsl:value-of select="$RES_PARAMETER_REVISION"/></font>
        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
        <font class="gray"><xsl:value-of select="($rev)"/></font>
        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </xsl:if>
    <saxon:assign name="globalIndex" select="$globalIndex+ 1"/>
    <font class="gray">
        [<xsl:value-of select="/ResultsSession/Exec/Categories/CategoryGroup/Category[@id=$cat]/@short"/>
        <xsl:if test="string-length($verifBy) > 0"><xsl:value-of select="$RES_PARAMETER_VERIFIED_BY"/>
    <xsl:value-of select="($verifBy)"/>     
    </xsl:if>]
     </font> 
    </td>
    <td style="padding-right:5px;" align="right" valign="top">
    <xsl:if test="$authorInfo = 'true'"> 
    <xsl:variable name="auth" select="@auth"/>
    <xsl:variable name="authid" select="/ResultsSession/Authors/Author[@name=($auth)]/@id"/>
    <xsl:call-template name="exec_author_link">
        <xsl:with-param name="auth" select="$auth"/>
        <xsl:with-param name="authid" select="$authid"/>
        <xsl:with-param name="link_class">gray_link</xsl:with-param>
        <xsl:with-param name="font_class">gray2</xsl:with-param>
        <xsl:with-param name="has_tasks">true</xsl:with-param>
    </xsl:call-template>
    </xsl:if>

    </td>   
    </tr>
    <xsl:if test="string-length($testParams) > 0">
    <tr>
    <xsl:if test="$simpleMode = 'false'">
        <td style="padding-left:5px;padding-right:5px;" colspan="3">
            <xsl:value-of select="$RES_PARAMETER_IMPUTS_OUTPUTS"/> <xsl:value-of select="($testParams)"/>
        </td>
    </xsl:if>
    <xsl:if test="$simpleMode = 'true'">
        <td style="padding-left:5px;padding-right:5px;" colspan="2">
            <xsl:value-of select="$RES_PARAMETER_IMPUTS_OUTPUTS"/> <xsl:value-of select="($testParams)"/>
        </td>
    </xsl:if>    
    </tr>
    </xsl:if>
    <xsl:call-template name="stack_trace"/>
    
    </xsl:otherwise>
    </xsl:choose>
    <saxon:assign name="tmp_file_name" select="$fileName"/>
    </xsl:if>
    <!-- Exclude unverified outcomes? -->
    <!--/xsl:if-->
    <xsl:if test="($urgent = 'true' and $urgent_err = 'true') or not($urgent = 'true')">
       <tr><td colspan="3"><br/></td></tr>
    </xsl:if>
    </xsl:for-each>
    </xsl:template>

    <!-- =================  insure error details ============================ -->
    
    <xsl:template name="insure_error_details">
        <xsl:param name="urgent"/>
        <xsl:param name="simpleMode"/>
    
    <!-- xsl:variable name="fileName" select="@resFile" saxon:assignable="yes"/>    
    <xsl:if test="string-length(@loc) > 0">
        <saxon:assign name="fileName" select="@loc"/>
    </xsl:if>     
    <xsl:if test="string-length(@uri) > 0">
        <saxon:assign name="fileName" select="@uri"/>
    </xsl:if-->     
    <xsl:variable name="cat" select="@cat"/>
    <!--xsl:variable name="msg" select="ElDescList/ElDesc/@desc"/-->
    <xsl:variable name="msg" select="@msg"/>
    <xsl:variable name="testName" select="@testName"/>
    <xsl:variable name="urgent_err" select="@urgent"/>
    <xsl:variable name="verifBy" select="@verifBy"/>
    <xsl:variable name="testParams" select="@testParams"/>
    <xsl:variable name="rev" select="@rev"/>
    
    <!-- Exclude unverified outcomes? -->
    <!--xsl:if test="not(($cat) = '6') and not(($cat) = '7')"-->
    <xsl:if test="$simpleMode = 'false' and string-length($testName) > 0">
    <tr>
    <td colspan="3" class="tree">
        <xsl:value-of select="$RES_PARAMETER_TEST_CASE"/><xsl:value-of select="($testName)"/>
    </td>
    </tr>
    </xsl:if>
    <tr>
    <td colspan="2" class="tree">
    <xsl:value-of select="($msg)" disable-output-escaping="no"/>
    <xsl:if test="(string-length($rev) > 0) and not($rev = 'unknown.revision')">
        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
        <font class="gray"><xsl:value-of select="$RES_PARAMETER_REVISION"/></font>
        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
        <font class="gray"><xsl:value-of select="($rev)"/></font>
        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </xsl:if>
    <font class="gray">
        [<xsl:value-of select="/ResultsSession/Exec/Categories/CategoryGroup/Category[@id=$cat]/@short"/>]
     </font> 
    </td>
    <td></td>   
    </tr>
    <xsl:if test="string-length($testParams) > 0">
    <tr>
    <td colspan="3" class="tree">
        <xsl:value-of select="$RES_PARAMETER_IMPUTS_OUTPUTS"/> <xsl:value-of select="($testParams)"/>
    </td>
    </tr>
    </xsl:if>
    <xsl:call-template name="insure_messages"/>
    <xsl:call-template name="insure_stack_trace"/>
    <xsl:call-template name="insure_alloc_stack_trace">
	    <xsl:with-param name="extra_ident">true</xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="insure_dealloc_stack_trace">
	    <xsl:with-param name="extra_ident">true</xsl:with-param>
    </xsl:call-template>
    <xsl:if test="$simpleMode = 'false'">    
    </xsl:if>
    <!-- Exclude unverified outcomes? -->
    <!--/xsl:if-->
    </xsl:template>

    <!-- =================  insure messages ================================================= -->

    <xsl:template name="insure_messages">
    <xsl:for-each select="ElDescList/ElDesc[@ElType='MSG' or @ElType='SRC']">
    <tr>
    <td colspan="2">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="@desc"/>
    </td>
    </tr>  
    <xsl:call-template name="insure_stack_trace">
	    <xsl:with-param name="extra_ident">true</xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="insure_alloc_stack_trace">
	    <xsl:with-param name="extra_ident">true</xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="insure_dealloc_stack_trace">
	    <xsl:with-param name="extra_ident">true</xsl:with-param>
    </xsl:call-template>
    </xsl:for-each>
    </xsl:template>

    <!-- =================  insure stack trace ============================================== -->

    <xsl:template name="insure_stack_trace">
    <xsl:param name="extra_ident"/>
    <xsl:for-each select="ElDescList/ElDesc[@ElType='ST']">
    <xsl:variable name="line" select="@ln"/>
    <xsl:variable name="fileName" select="@srcRngFile"/>
    <tr>
    <td colspan="3">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:if test="($extra_ident) = 'true'">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </xsl:if>
    <xsl:if test="($line &lt; 0) or not(string-length($fileName) > 0)"><xsl:value-of select="concat('at ',@desc)"/></xsl:if>
    <xsl:if test="($line > -1) and (string-length($fileName) > 0)"><xsl:value-of select="concat('at ','.','(',$fileName,':',$line,')')"/></xsl:if>
    </td>
    </tr>  
    </xsl:for-each>
    </xsl:template>
    
    <!-- =================  insure allocation stack trace ============================================== -->

    <xsl:template name="insure_alloc_stack_trace">
    <xsl:param name="extra_ident"/>
    
    <xsl:if test="count(AllocDescList/AllocDesc[@ElType='ST']) > 0">
    	<tr>
    	<td colspan="3">
    	<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    	<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    	<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    	<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    	<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    	<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    	<xsl:value-of select="concat($RES_ALLOCATION_STACK_TRACE,':')"/>
    	</td>
    	</tr>
    	<xsl:for-each select="AllocDescList/AllocDesc[@ElType='ST']">
    		<xsl:variable name="line" select="@ln"/>
    		<xsl:variable name="fileName" select="@srcRngFile"/>
    		<tr>
    		<td colspan="3">
    		<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    		<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    		<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
		    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    		<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
		    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    		<xsl:if test="($extra_ident) = 'true'">
    			<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    			<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    			<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    			<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    			<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    			<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    		</xsl:if>
    		<xsl:if test="($line &lt; 0) or not(string-length($fileName) > 0)"><xsl:value-of select="concat('at ',@desc)"/></xsl:if>
    		<xsl:if test="($line > -1) and (string-length($fileName) > 0)"><xsl:value-of select="concat('at ','.','(',$fileName,':',$line,')')"/></xsl:if>
    		</td>
		    </tr>  
    	</xsl:for-each>
    </xsl:if>
    </xsl:template>
    
    <!-- =================  insure deallocation stack trace ============================================== -->

    <xsl:template name="insure_dealloc_stack_trace">
    <xsl:param name="extra_ident"/>
    
    <xsl:if test="count(DeallocDescList/DeallocDesc[@ElType='ST']) > 0">
    	<tr>
    	<td colspan="3">
    	<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    	<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    	<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    	<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    	<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    	<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    	<xsl:value-of select="concat($RES_DEALLOCATION_STACK_TRACE,':')"/>
    	</td>
    	</tr>
    	<xsl:for-each select="DeallocDescList/DeallocDesc[@ElType='ST']">
    		<xsl:variable name="line" select="@ln"/>
    		<xsl:variable name="fileName" select="@srcRngFile"/>
    		<tr>
    		<td colspan="3">
    		<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    		<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    		<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
		    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    		<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
		    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    		<xsl:if test="($extra_ident) = 'true'">
    			<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    			<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    			<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    			<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    			<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    			<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    		</xsl:if>
    		<xsl:if test="($line &lt; 0) or not(string-length($fileName) > 0)"><xsl:value-of select="concat('at ',@desc)"/></xsl:if>
    		<xsl:if test="($line > -1) and (string-length($fileName) > 0)"><xsl:value-of select="concat('at ','.','(',$fileName,':',$line,')')"/></xsl:if>
    		</td>
		    </tr>  
    	</xsl:for-each>
    </xsl:if>
    </xsl:template>

    <!-- =================  print execution details for the auth ============================ -->
    
    <xsl:template name="exec_author_details">
    <xsl:param name="auth"/>
    <xsl:param name="authid"/>
    <xsl:param name="mode"/>
    <xsl:param name="urgent"/>
    
    <xsl:variable name="exec_total" select="tmp" saxon:assignable="yes"/>
    <xsl:if test="not($urgent = 'true')">
            <saxon:assign name="exec_total" select="count(/ResultsSession/Exec/ExecViols/*[@auth=($auth)])"/>
    </xsl:if>
    <xsl:if test="($urgent = 'true')">
            <saxon:assign name="exec_total" select="count(/ResultsSession/Exec/ExecViols/*[@auth=($auth) and @urgent='true'])"/>
    </xsl:if>
    
    <xsl:if test="($exec_total > 0)">                  
    	<xsl:variable name="anchor" saxon:assignable="yes" select="concat('te_urg_',$authid)"/>
	    <xsl:variable name="message" select="$RES_PARAMETER_RECOMMENDED_FINDINGS_TO_ACCOMPLISH" saxon:assignable="yes"/>    		    	
	    <xsl:if test="not(($urgent) = 'true')">	    
	    	<saxon:assign name="anchor" select="concat('te_',$authid)"/>
	    	<saxon:assign name="message" select="$RES_PARAMETER_TOTAL_FINDINGS"/>
	    </xsl:if>
	    <tr>     				   
	    	<xsl:call-template name="details_table_auth_header">
	    		<xsl:with-param name="auth" select="$auth"/>
	    		<xsl:with-param name="number" select="$exec_total"/>
	    		<xsl:with-param name="message" select="$message"/>    		    		
	    		<xsl:with-param name="anchor" select="$anchor"/>
	   	  	</xsl:call-template>   	  	   	  	   	    	    	    	
	    </tr>
        <tr><td colspan="3">
           <xsl:call-template name="print_header_separator"/>
        </td></tr>
    </xsl:if>

    <!-- total execution errors -->
    <xsl:if test="($exec_total) > 0">    
    	<xsl:variable name="errorsList" select="/ResultsSession/Exec/ExecViols/*[@auth=($auth)]"/>        
	    <tr>          
        <td align="left" colspan="3" >
   		<table class="doubleborder" aligh="center" width="100%" cellpadding='0' cellspacing='0'>
   		<xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">50% 25% 25%</xsl:attribute>
        </xsl:if>    	      
	    <xsl:call-template name="exec_error_details">
	       <xsl:with-param name="errorsList" select="($errorsList)"/>
	       <xsl:with-param name="urgent" select="($urgent)"/>
	       <xsl:with-param name="simpleMode" select="'false'"/>
	       <xsl:with-param name="authorInfo" select="'false'"/>
	    </xsl:call-template>
	    </table>
    	</td>
   		</tr>
    </xsl:if>
    
    <xsl:if test="($mode = 'single') or ($mode = 'summary' and ($exec_total > 0))">
    <tr>
    <td><br/></td>
    </tr>
    </xsl:if>
    
    </xsl:template>

    <!-- =================  print execution details for each auth ============================ -->
    
    <xsl:template name="exec_details">
        <xsl:for-each select="/ResultsSession/Authors/Author">
        
            <xsl:call-template name="exec_author_details">
                <xsl:with-param name="auth" select="@name"/>
                <xsl:with-param name="authid" select="@id"/>
                <xsl:with-param name="mode">summary</xsl:with-param>
            </xsl:call-template>
            
       </xsl:for-each> 
    </xsl:template>
    
    <!-- =================  te_author_subcategory_summary  ============================ -->
    
    <xsl:template name="te_author_subcategory_summary">
    <xsl:param name="subCategory"/>
    <xsl:param name="auth"/>
    <xsl:param name="authidx"/>
    <xsl:param name="urgent"/>
    
    <xsl:variable name="subCategoryCount" saxon:assignable="yes">0</xsl:variable>
    <xsl:variable name="subCategoryId" select="$subCategory/@id"/>
    <xsl:variable name="subCategoryName" select="$subCategory/@name"/>
    
    <xsl:if test="not(($urgent) = 'true')">
       <saxon:assign name="subCategoryCount" select="results:getTotalValue($subCategory/@authTot,$authidx)"/>
    </xsl:if>    
    <xsl:if test="($urgent) = 'true'">
       <saxon:assign name="subCategoryCount" select="results:getTotalValue($subCategory/@authUrg,$authidx)"/>
    </xsl:if>
    
    <xsl:if test="($subCategoryCount) > 0">
       <xsl:call-template name="te_error">
          <xsl:with-param name="name" select="$subCategoryName"/>
          <xsl:with-param name="total" select="($subCategoryCount)"/>
          <xsl:with-param name="level">2</xsl:with-param>
       </xsl:call-template>
       
       <xsl:for-each select="$subCategory/Type">
    
          <xsl:variable name="typeErrorCount" saxon:assignable="yes">0</xsl:variable>
          <xsl:if test="not(($urgent) = 'true')">
             <saxon:assign name="typeErrorCount" select="results:getTotalValue(./@authTot,$authidx)"/>
          </xsl:if>    
          <xsl:if test="($urgent) = 'true'">
             <saxon:assign name="typeErrorCount" select="results:getTotalValue(./@authUrg,$authidx)"/>
          </xsl:if>
    
          <xsl:call-template name="te_error">
             <xsl:with-param name="name" select="@name"/>
             <xsl:with-param name="total" select="$typeErrorCount"/>
             <xsl:with-param name="level">3</xsl:with-param>
          </xsl:call-template>
          
       </xsl:for-each>
    </xsl:if>
    </xsl:template>

    <!-- =================  te_author_error_summary  ============================ -->
    
    <xsl:template name="te_author_error_summary">
    <xsl:param name="auth"/>
    <xsl:param name="authidx"/>
    <xsl:param name="urgent"/>

    <xsl:for-each select="/ResultsSession/Exec/Categories/CategoryGroup">
    
       <xsl:variable name="categoryId" select="@id"/>
       
       <xsl:variable name="categoryCount" saxon:assignable="yes">0</xsl:variable>
       <xsl:if test="not(($urgent) = 'true')">
          <saxon:assign name="categoryCount" select="results:getTotalValue(./@authTot,$authidx)"/>
       </xsl:if>    
       <xsl:if test="($urgent) = 'true'">
          <saxon:assign name="categoryCount" select="results:getTotalValue(./@authUrg,$authidx)"/>
       </xsl:if>
       
       <xsl:if test="($categoryCount) > 0">
       
          <xsl:call-template name="te_error">
             <xsl:with-param name="name"><xsl:value-of select="@name"/></xsl:with-param>
             <xsl:with-param name="total" select="$categoryCount"/>
             <xsl:with-param name="level">1</xsl:with-param>
          </xsl:call-template>
          
          <xsl:for-each select="./Category">
             <xsl:call-template name="te_author_subcategory_summary">
                <xsl:with-param name="subCategory" select="."/>
                <xsl:with-param name="auth" select="$auth"/>
                <xsl:with-param name="authidx" select="$authidx"/>
                <xsl:with-param name="urgent" select="$urgent"/>
             </xsl:call-template>
          </xsl:for-each>
          
       </xsl:if>
    </xsl:for-each>

    </xsl:template>
    
    <!-- =================te_author_errors_summary ============================ -->
    
    <xsl:template name="te_author_errors_summary">
    <xsl:param name="auth"/>
    <xsl:param name="authidx"/>
    <xsl:param name="urgent"/>
    
    <table width='{$width}' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>
    <xsl:call-template name="te_summary_title">
    <xsl:with-param name="urgent" select="($urgent)"/>
    </xsl:call-template>    
    <tr>
    <td align="left">
    <table width='100%' class="doubleborder" cellpadding='0' cellspacing='0' >
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>
    <xsl:call-template name="te_author_error_summary">
       <xsl:with-param name="auth" select="($auth)"/>
       <xsl:with-param name="authidx" select="($authidx)"/>
       <xsl:with-param name="urgent" select="($urgent)"/>
    </xsl:call-template>
    </table>
    </td>
    </tr>    
    </table>
    </xsl:template>
            
    <!-- =================  print execution header ============================ -->
    
    <xsl:template name="exec_header">
    <xsl:param name="ref"/>
    <xsl:if test="string-length($ref) > 0">
    <a name="{$ref}"></a>
    </xsl:if>   
    <table class="header" width='{$width}' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">15% 70% 15%</xsl:attribute>
        </xsl:if>
    <tr>
    <td width="15%"></td>
    <td align="center">    
        <div class="header"><xsl:value-of select="$RES_PARAMETER_TEST_EXECUTION"/></div>
    </td>
    <td width="15%" align="right" valign="bottom">
	  	<xsl:if test="not($report_type = $email_report) and ($first_back_to_top = 'false')">
           <xsl:call-template name="back_to_top"/>
        </xsl:if>
   		<saxon:assign name="first_back_to_top">false</saxon:assign>
    </td>
    </tr>
    </table>
    </xsl:template>

    <!-- =================  print execution coverage header ============================ -->
    
    <xsl:template name="te_coverage_header">
    <a name="tec"></a>
    <table width='{$width}' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">        	
        	<xsl:attribute name="cols">30% 40% 30%</xsl:attribute>  			           
        </xsl:if>
    <tr>
    <td width="30%"/>
    
    <td width="40%" align="center">    
        <div class="small_header"><xsl:value-of select="$RES_PARAMETER_COVERAGE_HEADER"/></div>    
    </td>
    
	<td width="30%" align="right" nowrap="true">
	  	<xsl:if test="not($report_type = $email_report) and not($report_format_mode='pdf')">
	  	   <xsl:if test="($exec_cvg_details = 'true')">
				<xsl:variable name="href" saxon:assignable="yes" select="concat('javascript:openWin(',$qt,$cvg_html,$qt,')')"/>
	            <xsl:variable name="label" saxon:assignable="yes" select="$RES_PARAMETER_DETAILED_COVERAGE_REPORT"/>
		        <xsl:call-template name="standard_link_ref">
		           <xsl:with-param name="href" select="($href)"/>
		           <xsl:with-param name="label" select="($label)"/>
		           <xsl:with-param name="class">gray_red_link</xsl:with-param>
		        </xsl:call-template>
	  	   </xsl:if>

           <xsl:variable name="expand_cvg_details" select="'javascript:expandCvgDetails()'"/>   
           <xsl:variable name="collapse_cvg_details" select="'javascript:collapseCvgDetails()'"/>   
	  	   
           <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
           <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
           <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
	       <xsl:call-template name="standard_link_ref">
                <xsl:with-param name="href" select="$expand_cvg_details"/>
                <xsl:with-param name="label"><xsl:value-of select="$RES_PARAMETER_EXPAND_ALL"/></xsl:with-param>
                <xsl:with-param name="class">gray_red_link</xsl:with-param>
                <xsl:with-param name="id" select="expand_cvg_details"/>
                <xsl:with-param name="email_class">red2</xsl:with-param>
           </xsl:call-template>
           <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
           <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
           <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
           <xsl:call-template name="standard_link_ref">
                <xsl:with-param name="href" select="$collapse_cvg_details"/>
                <xsl:with-param name="label"><xsl:value-of select="$RES_PARAMETER_COLLAPSE_ALL"/></xsl:with-param>
                <xsl:with-param name="class">gray_red_link</xsl:with-param>
                <xsl:with-param name="id" select="collapse_cvg_details"/>
                <xsl:with-param name="email_class">red2</xsl:with-param>
           </xsl:call-template>
	  	   
           <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
           <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
           <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    	   <xsl:call-template name="back_to_top"/>
	  	</xsl:if>
  	</td>
    </tr>
    <tr><td colspan="3">
        <xsl:call-template name="print_header_separator"/>
    </td></tr>
    
    </table>
    </xsl:template>    
       
    <!-- =================  print test execution coverage summary  ============================ -->
    
    <xsl:template name="te_coverage_summary">
    <table class="doubleborder" width='100%' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>
    <tr>
       <td align="left">
         <saxon:assign name="isFirstRow">true</saxon:assign>
         <xsl:variable name="breakMode" select="boolean(count(/ResultsSession/Exec/Coverage/CvgStats//CvgInfo) &gt; $breakingThreshold)"/>         
          <xsl:if test="($exec_cvg) > 0">
             <ul class="root" id="cvg_foldinglist">
                 <saxon:assign name="globalIndex" select="0"/>
                
                <xsl:for-each select="/ResultsSession/Exec/Coverage/CvgStats/CvgInfo">
                    <xsl:call-template name="coverage_items">
                        <xsl:with-param name="depth" select="0"/>
                        <xsl:with-param name="singleType" select="count(/ResultsSession/Exec/Coverage/Types/CvgType) = 1"/>
                        <xsl:with-param name="breakMode" select="$breakMode"/>
                        <xsl:with-param name="canBreakHere" select="false"/>
                    </xsl:call-template>
                </xsl:for-each>
             </ul>
          </xsl:if>
          <xsl:if test="not(($exec_cvg) > 0)">
             <xsl:value-of select="$RES_PARAMETER_NOT_AVAILABLE"/>
          </xsl:if>
       </td>
    </tr>
    </table>
    </xsl:template>

    <!-- =================  print exec coverage items ============================ -->
    
    <xsl:template name="coverage_items">
        <xsl:param name="depth"/>
        <xsl:param name="singleType"/> 
        <xsl:param name="breakMode"/>        
        <xsl:param name="canBreakHere"/>

        <xsl:variable name="coverageStructItems" select="./CvgInfo[@exp='1']"/>                        
        <xsl:variable name="coverageItems" saxon:assignable="yes"/>
        <xsl:if test="($report_type = $email_report)">
           <saxon:assign name="coverageItems" select="$coverageStructItems"/>    
	    </xsl:if>
        <xsl:if test="not($report_type = $email_report)">          
           <saxon:assign name="coverageItems" select="./CvgInfo"/>    
	    </xsl:if>

        <xsl:variable name="numberChildren" select="count($coverageItems)"/>                        

        <xsl:call-template name="coverage_item">
            <xsl:with-param name="name" select="@elem"/>
            <xsl:with-param name="values" select="@val"/>
            <xsl:with-param name="numbers" select="@num"/>
            <xsl:with-param name="totals" select="@total"/>
            <xsl:with-param name="children" select="$numberChildren"/>
            <xsl:with-param name="singleType" select="$singleType"/>
        </xsl:call-template>
        <saxon:assign name="globalIndex" select="$globalIndex+ 1"/>    
        <xsl:variable name="childCounter" select="0" saxon:assignable="yes"/>
        
            <ul id="cvg_foldinglist">
                <xsl:if test="($depth &gt; 0) and not($report_type = $email_report)">
                    <xsl:attribute name="style">display:none</xsl:attribute>
                </xsl:if>                                               
                <xsl:for-each select="$coverageItems">                
                		<saxon:assign name="childCounter" select="$childCounter + 1"/>                		   
                        <xsl:call-template name="coverage_items">
                            <xsl:with-param name="depth" select="$depth + 1"/>
                            <xsl:with-param name="singleType" select="$singleType"/>                            
                            <xsl:with-param name="breakMode" select="$breakMode"/>
                            <xsl:with-param name="canBreakHere" select="not(boolean($childCounter = $numberChildren))"/>
                        </xsl:call-template>                                                                                   
                </xsl:for-each>
            </ul>        
            <xsl:if test="$canBreakHere">    
            <xsl:if test="$numberChildren &gt; 0">
            <xsl:if test="($report_format_mode='pdf')">
			<xsl:if test="$breakMode">
				<xsl:if test="$globalIndex &gt; $breakingSize">
					<BREAK-TABLE />
					<saxon:assign name="globalIndex" select="0" />
				</xsl:if>
			</xsl:if>
        	</xsl:if>
        	</xsl:if>
        	</xsl:if>
    </xsl:template>
 
    <!-- =================  print exec coverage item ============================ -->
    
    <xsl:template name="coverage_item">
        <xsl:param name="name"/>
        <xsl:param name="values"/>
        <xsl:param name="numbers"/>
        <xsl:param name="totals"/>
        <xsl:param name="children"/>
        <xsl:param name="singleType"/>
        
        <xsl:variable name="rowStyle" saxon:assignable="yes">tree</xsl:variable>
        <!--xsl:if test="$isFirstRow = 'true'">
           <saxon:assign name="rowStyle">root</saxon:assign>
           <saxon:assign name="isFirstRow" select="false"/>
        </xsl:if-->
        
        <xsl:variable name="li_id" saxon:assignable="yes">foldheader</xsl:variable>
        <xsl:variable name="vals" saxon:assignable="yes" select="$values"/>
        <xsl:if test="not(($children) > 0) or ($report_type = $email_report)">
            <saxon:assign name="li_id">item</saxon:assign>
        </xsl:if>
        
        <li id="{$li_id}" class="{$rowStyle}">
            <xsl:if test="not($report_type = $email_report) and ($children) > 0">
                <font class="gray">+</font>
            </xsl:if>
            <xsl:if test="not($report_type = $email_report) and ($children) = 0">
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            </xsl:if>
            <xsl:variable name="space" saxon:assignable="yes"/>
            <xsl:variable name="notCoverable" select="boolean($singleType) and not(@total &gt; 0)"/>
            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            <b><xsl:value-of select="($name)"/></b>
            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>[<xsl:for-each select="/ResultsSession/Exec/Coverage/Types/CvgType"><xsl:if test="boolean($notCoverable)"><xsl:value-of
            select="(@dispNoCvg)"/></xsl:if><xsl:if test="not(boolean($notCoverable))"><xsl:variable name="value" saxon:assignable="yes" select="substring-before(($vals),';')"/><xsl:if
            test="not(string-length($value) > 0)"><saxon:assign name="value" select="$vals"/></xsl:if><saxon:assign name="vals" select="substring-after(($vals),';')"/><xsl:if
            test="boolean($space)"><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/></xsl:if><xsl:if test="not(boolean($space))"><saxon:assign name="space"
            select="not($space)"/></xsl:if><xsl:if test="not(boolean($singleType))"><xsl:value-of select="(@dispId)"/>=</xsl:if><xsl:if test="($value) &lt; ($report.coverage.limit)"><font class="red"><b><xsl:value-of
            select="($value)"/></b></font></xsl:if><xsl:if test="not(($value) &lt; ($report.coverage.limit))"><b><xsl:value-of select="($value)"/></b></xsl:if><xsl:if test="boolean($singleType)">%<xsl:value-of
            select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="($numbers)"/>/<xsl:value-of select="($totals)"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of
            select="(@dispCvg)"/></xsl:if></xsl:if></xsl:for-each><xsl:if test="not(boolean($singleType))"><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>(%)</xsl:if>]
        </li>
    </xsl:template>
    
    <!-- =================  print ju coverage summary and authors errors  ============================ -->
    
    <xsl:template name="exec_coverage_summary">
        <xsl:if test="($exec_cvg) > 0">
            <table width='{$width}' cellpadding='0' cellspacing='0'>
                <xsl:if test="($report_format_mode='pdf')">
                    <xsl:attribute name="cols">100%</xsl:attribute>
                </xsl:if>
                <tr>
                    <td>
                        <xsl:call-template name="te_coverage_summary"/>
                    </td>
                </tr>
                <!-- xsl:if test="count(/ResultsSession/Exec/Coverage/Types/CvgType) &gt; 1">
                    <tr>
                        <td width="80%">
                            <table width='100%' cellpadding='0' cellspacing='0'>
                                <xsl:if test="($report_format_mode='pdf')">
                                    <xsl:attribute name="cols">100%</xsl:attribute>
                                </xsl:if>
                                <tr>
                                    <td>
                                        <br/>
                                        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><b><xsl:value-of select="$RES_PARAMETER_LEGEND"/></b>
                                        <br/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                    </td>
                                </tr>
                                <xsl:variable name="start_row" saxon:assignable="yes">true</xsl:variable>
                                
                                <xsl:if test="not($report_format_mode='pdf')">
                                    <xsl:for-each select="/ResultsSession/Exec/Coverage/Types/CvgType">
                                        <xsl:if test="boolean($start_row)">
                                            <tr/>
                                        </xsl:if>
                                        <td>
                                            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                            <b><xsl:value-of select="@dispId"/></b> - <xsl:value-of select="@dispName"/><br/>
                                        </td>
                                        <saxon:assign name="start_row" select="not($start_row)"/>
                                    </xsl:for-each>
                                </xsl:if>
                                <xsl:if test="($report_format_mode='pdf')">
                                    <xsl:for-each select="/ResultsSession/Exec/Coverage/Types/CvgType">
                                        <tr>
                                            <td>
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                                <b><xsl:value-of select="@dispId"/></b> - <xsl:value-of select="@dispName"/><br/>
                                            </td>
                                        </tr>
                                        <saxon:assign name="start_row" select="not($start_row)"/>
                                    </xsl:for-each>
                                </xsl:if>
                            </table>
                        </td>
                    </tr>
                </xsl:if-->
            </table>
        </xsl:if>
    </xsl:template>    
        
        
    <!-- =================  print executed tests details  ============================ -->
    
    <xsl:template name="executed_tests_details">
        <xsl:if test="($exec_details) > 0">
            <table width='{$width}' cellpadding='0' cellspacing='0'>
                <xsl:if test="($report_format_mode='pdf')">
                    <xsl:attribute name="cols">100%</xsl:attribute>
                </xsl:if>               
                <tr>
                    <td>
                        <xsl:call-template name="executed_tests_files_summary"/>
                    </td>
                </tr>
            </table>
        </xsl:if>
    </xsl:template>    
    
    <!-- =================  print executed tests summary ============================ -->
    
    <xsl:template name="executed_tests_files_summary">
    
       <xsl:variable name="expand_exec_details" select="'javascript:expandExecDetails()'"/>   
       <xsl:variable name="collapse_exec_details" select="'javascript:collapseExecDetails()'"/>   
    
       <table class="singleborder" width='100%' cellpadding='0' cellspacing='0'>
          <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
          </xsl:if>               
       <tr><td>
         <table width="100%" cellpadding="0" cellspacing="0">
             <xsl:if test="($report_format_mode='pdf')">
               <xsl:attribute name="cols">100%</xsl:attribute>
             </xsl:if>               
          <tr>
          <xsl:if test="not(($report_type) = ($email_report)) and not($report_format_mode='pdf')">          
            <td width="40%"></td>
          </xsl:if>
          <td width="20%" align='center'>
            <div class="small_header"><xsl:value-of select="$RES_PARAMETER_EXECUTED_TESTS_DETAILS"/></div>

          </td>
          <xsl:if test="not(($report_type) = ($email_report)) and not($report_format_mode='pdf')">          
          <td align="right" width="40%">
             <xsl:call-template name="standard_link_ref">
                <xsl:with-param name="href" select="$expand_exec_details"/>
                <xsl:with-param name="label"><xsl:value-of select="$RES_PARAMETER_EXPAND_ALL"/></xsl:with-param>
                <xsl:with-param name="class">gray_red_link</xsl:with-param>
                <xsl:with-param name="id" select="expand_exec_details"/>
                <xsl:with-param name="email_class">red2</xsl:with-param>
             </xsl:call-template>
             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
             <xsl:call-template name="standard_link_ref">
                <xsl:with-param name="href" select="$collapse_exec_details"/>
                <xsl:with-param name="label"><xsl:value-of select="$RES_PARAMETER_COLLAPSE_ALL"/></xsl:with-param>
                <xsl:with-param name="class">gray_red_link</xsl:with-param>
                <xsl:with-param name="id" select="collapse_exec_details"/>
                <xsl:with-param name="email_class">red2</xsl:with-param>
             </xsl:call-template>
             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
             <xsl:call-template name="back_to_top"/>
          </td>
          </xsl:if> 
          </tr>
        </table>
       </td></tr>
       <tr><td>
            <xsl:call-template name="print_header_separator"/>
       </td></tr>
       <tr><td>
       <table class="doubleborder" aligh="center" width="100%">
        <xsl:if test="($report_format_mode='pdf')">
          <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>
       <tr><td align="left">
          <xsl:if test="($exec_details) > 0">
          	<saxon:assign name="globalIndex" select="0"/>
            <saxon:assign name="isFirstRow">true</saxon:assign>
          	
            <ul class="root" id="exec_foldinglist">	  
            <xsl:for-each select="/ResultsSession/Exec/ExecutedTestsDetails/*">
                <xsl:call-template name="executed_tests_tree">
                    <xsl:with-param name="depth">0</xsl:with-param>
                    <xsl:with-param name="canBreakHere" select="false"/>
                </xsl:call-template>
            </xsl:for-each>
            </ul>
          </xsl:if>
          <xsl:if test="not(($exec_details) > 0)">
            <xsl:value-of select="$RES_PARAMETER_NOT_AVAILABLE"/>
          </xsl:if>
       </td></tr>
       </table>
       </td></tr>
       </table>
    </xsl:template>

	<!-- ================= display executed tests tree nodes ============================ -->

  <xsl:template name="executed_tests_tree">
    <xsl:param name="depth" />
    <xsl:param name="canBreakHere" />

    <xsl:variable name="errorsCount" saxon:assignable="yes">0</xsl:variable>
    <xsl:variable name="errorsList" saxon:assignable="yes" />
    <xsl:variable name="testId" select="@id" />

    <xsl:if test="boolean($report.developer_errors = 'true' and (name() = 'Test') and string-length($testId) > 0)">
      <saxon:assign name="errorsList" select="key('execViolKey',@id)" />
      <saxon:assign name="errorsCount" select="count($errorsList)" />
    </xsl:if>

    <xsl:variable name="isExpandable" select="0" saxon:assignable="yes" />
    <saxon:assign name="isExpandable"
			select="boolean(not($report_type = $email_report) and (((count(./Project | ./Test | ./TestSuite | ./TestCase) > 0) or $errorsCount > 0)  or (($report.associations = 'true') and (count(./assoc) > 0))))" />
    <xsl:if test="($report_format_mode='pdf')">
      <xsl:if test="$canBreakHere">
        <xsl:if test="$globalIndex &gt; $breakingSize">
          <BREAK-TABLE />
          <saxon:assign name="globalIndex" select="0" />
        </xsl:if>
      </xsl:if>
    </xsl:if>

    <xsl:if test="boolean(not(name() = 'Detail'))">

      <xsl:variable name="detailsCount" saxon:assignable="yes">0</xsl:variable>
      <xsl:if test="(name() = 'Test') and (($report.testcases_details) = 'true')">
        <saxon:assign name="detailsCount" select="count(./Detail)" />
        <saxon:assign name="isExpandable" select="boolean($isExpandable or $detailsCount > 0)"/>
      </xsl:if>

      <xsl:call-template name="executed_tests_tree_node">
        <xsl:with-param name="name" select="@name" />
        <xsl:with-param name="assoc" select="@assoc" />
        <xsl:with-param name="fail" select="@fail" />
        <xsl:with-param name="pass" select="@pass" />
        <xsl:with-param name="err" select="@err" />
        <xsl:with-param name="time" select="@time" />
        <xsl:with-param name="depth" select="$depth" />
        <xsl:with-param name="expandable" select="$isExpandable" />
      </xsl:call-template>

      <ul id="exec_foldinglist">
        <xsl:if test="($depth > 0) and not($report_type = $email_report)">
          <xsl:attribute name="style">display:none</xsl:attribute>
        </xsl:if>
        <xsl:if test="(($report.associations = 'true') and (count(./assoc) > 0))">
          <li id="item">
            <table width="75%" class="details">
            <xsl:if test="($report_format_mode='pdf')">
                <xsl:attribute name="cols">100%</xsl:attribute>
            </xsl:if>
            <tr>
               <td style="padding-left:5px;padding-right:5px;">
               <xsl:call-template name="associations_line"/>
               </td>
            </tr>
            </table>
          </li>
        </xsl:if>

        <xsl:if test="$detailsCount > 0">

            <li id="item">
              <table width="75%" class="details">
                <xsl:if test="($report_format_mode='pdf')">
                  <xsl:attribute name="cols">75% 25%</xsl:attribute>
                </xsl:if>
                
                <xsl:for-each select="./Detail">
                    <xsl:call-template name="executed_test_detail">
                        <xsl:with-param name="depth" select="$depth + 1"/>
                        <xsl:with-param name="type"><xsl:value-of select="@type"/></xsl:with-param>
                        <xsl:with-param name="msg"><xsl:value-of select="@msg"/></xsl:with-param>
                        <xsl:with-param name="sev"><xsl:value-of select="@sev"/></xsl:with-param>
                    </xsl:call-template>
                </xsl:for-each>
              </table>
            </li>

        </xsl:if>

        <xsl:variable name="testCasesCount" select="count(./TestCase)" />

        <xsl:if test="($errorsCount > 0) and ($testCasesCount = 0) and ($report.developer_errors = 'true')">
          <li id="item">
            <xsl:call-template name="executed_tests_violations">
              <xsl:with-param name="errorsList" select="$errorsList" />
            </xsl:call-template>
          </li>
        </xsl:if>

        <xsl:for-each select="./TestCase">
        
          <xsl:variable name="testCasesDetailsCount" saxon:assignable="yes">0</xsl:variable>
          <xsl:if test="($report.testcases_details) = 'true'">
             <saxon:assign name="testCasesDetailsCount" select="count(./Detail)" />
          </xsl:if>

          <xsl:variable name="testCaseErrorsList" saxon:assignable="yes"/>
          <xsl:variable name="testCaseErrorsListCount" saxon:assignable="yes">0</xsl:variable>
          <xsl:if test="($report.developer_errors = 'true') and ($errorsCount > 0)">
             <xsl:variable name="testCaseId" select="@id"/>            
             <saxon:assign name="testCaseErrorsList" select="$errorsList[@tcId=$testCaseId]"/>
             <saxon:assign name="testCaseErrorsListCount" select="count($testCaseErrorsList)" />
          </xsl:if>
        
          <xsl:call-template name="executed_tests_tree_node">
            <xsl:with-param name="depth" select="$depth + 1"/>
            <xsl:with-param name="name" select="@name"/>
            <xsl:with-param name="fail" select="@status = 'fail'"/>
            <xsl:with-param name="err" select="@status = 'err'"/>
            <xsl:with-param name="expandable" select="boolean(($testCasesDetailsCount > 0) or ($testCaseErrorsListCount > 0))" />
          </xsl:call-template>

          <ul id="exec_foldinglist">
            <xsl:if test="$testCasesDetailsCount > 0">
            <li id="item">
              <table width="75%" class="details">
                <xsl:if test="($report_format_mode='pdf')">
                  <xsl:attribute name="cols">75% 25%</xsl:attribute>
                </xsl:if>
                <xsl:for-each select="./Detail">
                    <xsl:call-template name="executed_test_detail">
                        <xsl:with-param name="depth" select="$depth + 1"/>
                        <xsl:with-param name="type"><xsl:value-of select="@type"/></xsl:with-param>
                        <xsl:with-param name="msg"><xsl:value-of select="@msg"/></xsl:with-param>
                        <xsl:with-param name="sev"><xsl:value-of select="@sev"/></xsl:with-param>
                    </xsl:call-template>
                </xsl:for-each>
              </table>
            </li>
            </xsl:if>

            <xsl:if test="$testCaseErrorsListCount > 0">
               <li id="item">
                  <xsl:call-template name="executed_tests_violations">
                     <xsl:with-param name="errorsList" select="$testCaseErrorsList" />
                  </xsl:call-template>
               </li>
            </xsl:if>
          </ul>

        </xsl:for-each>

        <xsl:variable name="childCounter" select="0" saxon:assignable="yes" />
        <xsl:for-each select="./Project | ./Test | ./TestSuite">
          <xsl:sort select="@name" />
          <saxon:assign name="childCounter" select="$childCounter + 1" />
          <xsl:call-template name="executed_tests_tree">
            <xsl:with-param name="depth" select="$depth + 1" />
            <xsl:with-param name="canBreakHere" select="($errorsCount > 0) or ($childCounter > 1)" />
          </xsl:call-template>
        </xsl:for-each>
      </ul>

    </xsl:if>
  </xsl:template>
  
    
	<!-- ================= print text with preserving line breaks ============================ -->
	<xsl:template name="text_line_breaks_links">
        <xsl:param name="text"/>
        <xsl:choose>
            <xsl:when test="contains($text,'&#xA;')">
            	<xsl:call-template name="handle_links">
                   	<xsl:with-param name="text">
                		<xsl:value-of select="substring-before($text,'&#xA;')"/>
                   	</xsl:with-param>
                </xsl:call-template>
                
                <br/>
                <xsl:call-template name="text_line_breaks_links">
                    <xsl:with-param name="text">
                        <xsl:value-of select="substring-after($text,'&#xA;')"/>
                    </xsl:with-param>
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
            	<xsl:call-template name="handle_links">
                   	<xsl:with-param name="text">
                		<xsl:value-of select="$text"/>
                   	</xsl:with-param>
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <!-- ================= handle html links ============================ -->
	<xsl:template name="handle_links">
        <xsl:param name="text"/>
        <xsl:choose>
            <xsl:when test="contains($text, 'http://')">
                <xsl:value-of select="substring-before($text,'http://')"/>
                <xsl:variable name="linkAndRest"
					select="substring($text, string-length(substring-before($text,'http://')))" />
                <xsl:choose>
            		<xsl:when test="contains($linkAndRest, ' ')">
            			<a>
            				<xsl:attribute name="href">
            					<xsl:value-of select="substring-before($linkAndRest,' ')" />
            				</xsl:attribute>
            				<b>
            					<xsl:value-of select="substring-before($linkAndRest,' ')" />
            				</b>
            			</a>
            			<xsl:value-of select="($nbsp)" disable-output-escaping="yes" />
            			<xsl:call-template name="handle_links">
                    		<xsl:with-param name="text">
                        		<xsl:value-of select="substring-after($linkAndRest,' ')"/>
                    		</xsl:with-param>
                		</xsl:call-template>
            		</xsl:when>
            		<xsl:otherwise>
                		<a><xsl:attribute name="href"><xsl:value-of select="$linkAndRest"/></xsl:attribute>
   							<b><xsl:value-of select="$linkAndRest" /></b></a>
            		</xsl:otherwise>
        		</xsl:choose>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$text"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
	<!-- ================= print executed tests details tree node ============================ -->
    
    <xsl:template name="executed_tests_tree_node">
        <xsl:param name="name"/>
        <xsl:param name="assoc"/>
        <xsl:param name="fail"/>
        <xsl:param name="pass"/>
        <xsl:param name="err"/>
        <xsl:param name="time"/>
        <xsl:param name="depth"/>
        <xsl:param name="expandable"/>
        <xsl:variable name="li_id" saxon:assignable="yes">exec_foldheader</xsl:variable>
        <xsl:if test="not($expandable)">
            <saxon:assign name="li_id">item</saxon:assign>
        </xsl:if>

        <xsl:variable name="rowStyle" saxon:assignable="yes">tree</xsl:variable>
        <!--xsl:if test="$isFirstRow = 'true'">
           <saxon:assign name="rowStyle">root</saxon:assign>
           <saxon:assign name="isFirstRow" select="false"/>
        </xsl:if-->

        <xsl:variable name="errCnt" saxon:assignable="yes">0</xsl:variable>
        <xsl:variable name="error_mode_enabled" saxon:assignable="yes">false</xsl:variable>
        <xsl:if test="$err">
           <saxon:assign name="errCnt" select="$err"/>
          <saxon:assign name="error_mode_enabled">true</saxon:assign>
        </xsl:if>

        <xsl:variable name="font_style" saxon:assignable="yes" select="'green'"/>
        <xsl:if test="($fail > 0)">
            <saxon:assign name="font_style" select ="'red'"/>
        </xsl:if>
        <!-- if errors are displayed show failers in blue and errors in red -->      
        <xsl:if test="($error_mode_enabled = 'true')">           
           <xsl:if test="($fail > 0)">
              <saxon:assign name="font_style" select ="'red'"/>
           </xsl:if>      
           <!-- incompleted has higher priority to display -->  
           <xsl:if test="($errCnt > 0)">
              <saxon:assign name="font_style" select ="'goldenrod'"/>
           </xsl:if>        
        </xsl:if>      
        
        <li id="{$li_id}" class="{$rowStyle}">
            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            <xsl:if test="$expandable = 'true'">
                <font class="gray">+</font>
            </xsl:if>
            <xsl:if test="not($expandable = 'true')">
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            </xsl:if>
            
            <xsl:if test="($pass + $fail + $errCnt > 1)">
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>[<font class="{$font_style}"><b><xsl:value-of
                    select="($pass)"/></b></font>/<font class="{$font_style}"><b><xsl:value-of select="$pass + $fail + $errCnt"/></b></font>]
            </xsl:if>
            
            <xsl:if test="not($pass + $fail + $errCnt > 1)">
		       <xsl:variable name="status_msg" saxon:assignable="yes" select="'P'"/> <!--select="$RES_PARAMETER_PASSED_TEST_CASES_LOWERCASE"/-->
               <xsl:if test="($fail > 0)">
                  <saxon:assign name="status_msg" select="'F'"/> <!--select ="$RES_PARAMETER_FAILED_TEST_CASES_LOWERCASE"/-->
               </xsl:if>
               <xsl:if test="($errCnt > 0)">
                  <saxon:assign name="status_msg" select="'I'"/> <!--select ="$RES_PARAMETER_INCOMPLETE_TEST_CASES_LOWERCASE"/-->
               </xsl:if>
               <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>[<font class="{$font_style}"><b><xsl:value-of select="$status_msg"/></b></font>]
            </xsl:if>

            <xsl:if test="string-length($time) > 0">
            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>[<xsl:value-of select="$time"/>]
            </xsl:if>
            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            <font class="black"><b><xsl:value-of select="($name)"/></b></font>                       
        	<saxon:assign name="globalIndex" select="$globalIndex+ 1"/>
        </li>
    </xsl:template>
  
    <xsl:template name="executed_test_detail">
        <xsl:param name="depth"/>
        <xsl:param name="type"/>
        <xsl:param name="msg"/>
        <xsl:param name="sev"/>

        <xsl:if test="string-length($msg) > 0">
            <tr>
              <td style="padding-left:5px;">
                <xsl:choose>
                    <xsl:when test="($sev) = 'High'">
                        <font class="red"><xsl:value-of select="$msg"/></font>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:call-template name="text_line_breaks_links">
                            <xsl:with-param name="text" select="$msg"/>
                        </xsl:call-template>
                    </xsl:otherwise>
                </xsl:choose>
              </td>
            </tr>
         </xsl:if>
    </xsl:template>
    
    <!-- =================  print executed tests violations  ============================ -->
    
    <xsl:template name="executed_tests_violations">
        <xsl:param name="errorsList"/>
        
        <table width="89%" class="details">
            <xsl:if test="($report_format_mode='pdf')">
                <xsl:attribute name="cols">50% 25% 25%</xsl:attribute>
            </xsl:if>            
            <xsl:call-template name="exec_error_details">
               <xsl:with-param name="errorsList" select="($errorsList)"/>
               <xsl:with-param name="urgent" select="'false'"/>
	       <xsl:with-param name="simpleMode" select="'true'"/>
               <xsl:with-param name="authorInfo" select="'true'"/>
            </xsl:call-template>
        </table>
    </xsl:template>            
    
</xsl:stylesheet>
